from typing import Any, Dict, Optional

from com.inductiveautomation.ignition.common import BasicDataset
from dev.thecesrom.helper.types import AnyStr

def addDevice(
    deviceType: AnyStr,
    deviceName: AnyStr,
    deviceProps: Dict[AnyStr, Any],
    description: Optional[AnyStr] = ...,
) -> None: ...
def getDeviceHostname(deviceName: AnyStr) -> AnyStr: ...
def listDevices() -> BasicDataset: ...
def refreshBrowse(deviceName: AnyStr) -> None: ...
def removeDevice(deviceName: AnyStr) -> None: ...
def restart(deviceName: AnyStr) -> None: ...
def setDeviceEnabled(deviceName: AnyStr, enabled: bool) -> None: ...
def setDeviceHostname(deviceName: AnyStr, hostname: AnyStr) -> None: ...



from typing import Any, Iterable, Optional, Union

from dev.thecesrom.helper.types import AnyStr

class Logger:
    ROOT_LOGGER_NAME: str
    def debug(self, *args: Any) -> None: ...
    def error(self, *args: Any) -> None: ...
    def getName(self) -> AnyStr: ...
    def info(self, *args: Any) -> None: ...
    def isErrorEnabled(self, marker: Optional[Marker] = ...) -> bool: ...
    def isInfoEnabled(self, marker: Optional[Marker] = ...) -> bool: ...
    def isTraceEnabled(self, marker: Optional[Marker] = ...) -> bool: ...
    def isWarnEnabled(self, marker: Optional[Marker] = ...) -> bool: ...
    def trace(self, *args: Any) -> None: ...
    def warn(self, *args: Any) -> None: ...

class Marker:
    ANY_MARKER: str
    ANY_NON_NULL_MARKER: str
    def add(self, reference: Marker) -> None: ...
    def contains(self, arg: Union[Marker, AnyStr]) -> bool: ...
    def equals(self, o: Any) -> bool: ...
    def getName(self) -> AnyStr: ...
    def hashCode(self) -> int: ...
    def hasReferences(self) -> bool: ...
    def iterator(self) -> Iterable[Marker]: ...
    def remove(self, reference: Marker) -> bool: ...



from typing import Any, Callable, Dict, List, Optional

from com.inductiveautomation.ignition.common.script.builtin.http import JythonHttpClient
from dev.thecesrom.helper.types import AnyStr

def getExternalIpAddress() -> AnyStr: ...
def getHostName() -> AnyStr: ...
def getIpAddress() -> AnyStr: ...
def getRemoteServers(runningOnly: Optional[bool] = ...) -> List[AnyStr]: ...
def httpClient(
    timeout: int = ...,
    bypass_cert_validation: bool = ...,
    username: Optional[AnyStr] = ...,
    password: Optional[AnyStr] = ...,
    proxy: Optional[AnyStr] = ...,
    cookie_policy: AnyStr = ...,
    redirect_policy: AnyStr = ...,
    version: AnyStr = ...,
    customizer: Optional[Callable[..., Any]] = ...,
) -> JythonHttpClient: ...
def httpDelete(
    url: AnyStr,
    contentType: Optional[AnyStr] = ...,
    connectTimeout: int = ...,
    readTimeout: int = ...,
    username: Optional[AnyStr] = ...,
    password: Optional[AnyStr] = ...,
    headerValues: Optional[Dict[AnyStr, AnyStr]] = ...,
    bypassCertValidation: bool = ...,
) -> AnyStr: ...
def httpGet(
    url: AnyStr,
    connectTimeout: int = ...,
    readTimeout: int = ...,
    username: Optional[AnyStr] = ...,
    password: Optional[AnyStr] = ...,
    headerValues: Optional[Dict[AnyStr, AnyStr]] = ...,
    bypassCertValidation: Optional[bool] = ...,
    useCaches: bool = ...,
    throwOnError: bool = ...,
) -> AnyStr: ...
def httpPost(url: AnyStr, *args: Any, **kwargs: Any) -> AnyStr: ...
def httpPut(url: AnyStr, *args: Any, **kwargs: Any) -> AnyStr: ...
def openURL(url: AnyStr, useApplet: Optional[bool] = ...) -> None: ...
def sendEmail(
    smtp: Optional[AnyStr] = ...,
    fromAddr: AnyStr = ...,
    subject: Optional[AnyStr] = ...,
    body: Optional[AnyStr] = ...,
    html: bool = ...,
    to: Optional[List[AnyStr]] = ...,
    attachmentNames: Optional[List[object]] = ...,
    attachmentData: Optional[List[object]] = ...,
    timeout: int = ...,
    username: Optional[AnyStr] = ...,
    password: Optional[AnyStr] = ...,
    priority: AnyStr = ...,
    smtpProfile: Optional[AnyStr] = ...,
    cc: Optional[List[AnyStr]] = ...,
    bcc: Optional[List[AnyStr]] = ...,
    retries: int = ...,
    replyTo: Optional[List[AnyStr]] = ...,
) -> None: ...



from typing import Any, List

from com.inductiveautomation.ignition.common import Path, QualifiedPath
from com.inductiveautomation.ignition.common.config import Property
from dev.thecesrom.helper.types import AnyStr
from java.lang import Class, Enum, Object
from java.util import Date

class EventProperty(Object):
    @staticmethod
    def create(prop: Property, type: EventPropertyType) -> EventProperty: ...
    @staticmethod
    def createDynamic(prop: Property, isConfig: bool) -> EventProperty: ...
    @staticmethod
    def createStatic(prop: Property, isConfig: bool) -> EventProperty: ...
    def getDefaultValue(self) -> Object: ...
    def getName(self) -> AnyStr: ...
    def getPropertyType(self) -> EventPropertyType: ...
    def getType(self) -> Class: ...

class EventPropertyType(Enum):
    @staticmethod
    def values() -> List[EventPropertyType]: ...

class ShelvedPath(Object):
    def __init__(self, *args: Any) -> None: ...
    def getExpiration(self) -> Date: ...
    def getHitCount(self) -> int: ...
    def getPath(self) -> Path: ...
    def getShelveTime(self) -> Date: ...
    def getUser(self) -> QualifiedPath: ...
    def incrementHitCount(self) -> None: ...
    def isExpired(self) -> bool: ...



from typing import Any, Iterable, List, Optional, Union

from dev.thecesrom.helper.types import AnyStr
from java.io import Closeable
from java.lang import AutoCloseable, Class, Comparable, Enum, Object, Throwable
from java.util import Date
from org.apache.commons.lang3.builder import ToStringStyle
from org.slf4j import Logger

class LoggerEx(Object):
    DEFAULT_TO_STRING_STYLE: ToStringStyle
    def createSubLogger(self, arg: Union[Class, AnyStr]) -> LoggerEx: ...
    def debug(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def debugDuration(self, message: AnyStr) -> Closeable: ...
    def debugEvent(self, message: AnyStr, *args: Any) -> None: ...
    def debugf(self, message: AnyStr, *args: Any) -> None: ...
    def error(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def errorEvent(self, message: AnyStr, *args: Any) -> None: ...
    def errorf(self, message: AnyStr, *args: Any) -> None: ...
    def fatal(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def getIdentObject(self) -> Object: ...
    def getLoggerSLF4J(self) -> Logger: ...
    def getName(self) -> AnyStr: ...
    def getToStringStyle(self) -> ToStringStyle: ...
    def info(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def infoDuration(self, message: AnyStr) -> Closeable: ...
    def infoEvent(self, message: AnyStr, *args: Any) -> None: ...
    def infof(self, message: AnyStr, *args: Any) -> None: ...
    def isDebugEnabled(self) -> bool: ...
    def isIdentObjectEnabled(self) -> bool: ...
    def isInfoEnabled(self) -> bool: ...
    def isTraceEnabled(self) -> bool: ...
    def mdcClose(self) -> None: ...
    def mdcPut(self, key: AnyStr, value: AnyStr) -> None: ...
    def mdcPutCloseable(self, key: AnyStr, value: AnyStr) -> LoggerEx.MDCCloseable: ...
    def mdcRemove(self, key: AnyStr) -> None: ...
    def mdcSet(self) -> LoggerEx.MDCCloseable: ...
    @staticmethod
    def newBuilder() -> LoggerEx.Builder: ...
    def setIdentObject(self, identObj: Object) -> None: ...
    def setToStringStyle(self, toStringStyle: ToStringStyle) -> None: ...
    def trace(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def traceDuration(self, message: AnyStr) -> Closeable: ...
    def traceEvent(self, message: AnyStr, *args: Any) -> None: ...
    def tracef(self, message: AnyStr, *args: Any) -> None: ...
    def warn(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def warnEvent(self, message: AnyStr, *args: Any) -> None: ...
    def warnf(self, message: AnyStr, *args: Any) -> None: ...

    class Builder(Object):
        def build(self, *args: Any) -> LoggerEx: ...
        def eventSystem(self, systemId: str) -> LoggerEx.Builder: ...
        def identObject(self, identObj: Object) -> LoggerEx.Builder: ...
        def mdcContext(self, *args: Object) -> LoggerEx.Builder: ...
        def mutableIdentObject(self, identObj: Object) -> LoggerEx.Builder: ...

    class MDCCloseable(Object, AutoCloseable):
        def close(self) -> None: ...

class Platform(Object):
    LINUX_AARCH64: Platform
    LINUX_ARM: Platform
    LINUX_X64: Platform
    LINUX_X86: Platform
    OSX_X64: Platform
    OSX_X86: Platform
    WINDOWS_X64: Platform
    WINDOWS_X86: Platform
    def __init__(
        self,
        operatingSystem: Platform.OperatingSystem,
        architecture: Platform.Architecture,
    ) -> None: ...
    def getArchitecture(self) -> Platform.Architecture: ...
    @staticmethod
    def getCurrent() -> Platform: ...
    def getOperatingSystem(self) -> Platform.OperatingSystem: ...

    class Architecture(Enum):
        @staticmethod
        def fromString(s: AnyStr) -> Platform.Architecture: ...
        def getSignatures(self) -> Iterable[AnyStr]: ...
        @staticmethod
        def values() -> Iterable[Platform.Architecture]: ...

    class OperatingSystem(Enum):
        @staticmethod
        def fromString(s: AnyStr) -> Platform.OperatingSystem: ...
        def getSignatures(self) -> Iterable[AnyStr]: ...
        @staticmethod
        def values() -> Iterable[Platform.OperatingSystem]: ...

class TimelineList(Object):
    def __init__(self) -> None: ...
    def add(self, *args: Any) -> None: ...
    def covered(self, time: long) -> bool: ...
    def get(self, time: long) -> Any: ...
    def getClosest(self, time: long) -> Any: ...
    def getSegment(self, *args: Any) -> TimelineList.TimeSegment: ...
    def getSegments(self, *args: Any) -> List[TimelineList.TimeSegment]: ...
    def mergeSegments(self) -> None: ...
    def nextEvent(self, time: long, allowRollover: Optional[bool] = ...) -> bool: ...
    def size(self) -> int: ...
    def sort(self) -> None: ...

    class TimeSegment(Object, Comparable):
        def __init__(self, *args: Any) -> None: ...
        def compareTo(self, o: Any) -> int: ...
        def contains(self, time: long) -> bool: ...
        def endsBefore(self, time: long) -> bool: ...
        def getDuration(self) -> long: ...
        def getEnd(self) -> long: ...
        def getStart(self) -> long: ...
        def getValue(self) -> Any: ...
        def setEnd(self, end: long) -> None: ...
        def setStart(self, start: long) -> None: ...
        def setStartAfter(self, start: long) -> None: ...

class Timeline(TimelineList):
    def __init__(self, style: Optional[Timeline.TimelineStyle] = ...) -> None: ...
    def addSegment(self, start: long, end: long) -> None: ...
    @staticmethod
    def createParser(style: Timeline.TimelineStyle) -> Timeline.TimelineParser: ...
    def getStyle(self) -> Timeline.TimelineStyle: ...
    def invert(self) -> Timeline: ...

    class TimelineParser:
        def parse(self, input: AnyStr) -> Timeline: ...

    class TimelineStyle(Enum):
        def toDateForStyle(self, value: long) -> Date: ...
        def toLongForStyle(self, dateMillis: Union[Date, long]) -> long: ...
        @staticmethod
        def values() -> Iterable[Timeline.TimelineStyle]: ...



from typing import List

from java.lang import Enum

class RoundingMode(Enum):
    CEILING: RoundingMode
    DOWN: RoundingMode
    FLOOR: RoundingMode
    HALF_DOWN: RoundingMode
    HALF_EVEN: RoundingMode
    HALF_UP: RoundingMode
    UNNECESSARY: RoundingMode
    UP: RoundingMode
    @staticmethod
    def values() -> List[RoundingMode]: ...



from typing import Iterable

from com.palantir.ptoss.cinch.core import DefaultBindableModel
from dev.thecesrom.helper.types import AnyStr
from java.lang import Enum

class ScheduleModel(DefaultBindableModel):
    def __init__(self) -> None: ...
    def deselectDayOfWeek(self, day: ScheduleModel.DayOfWeek) -> None: ...
    def getEveryHour(self) -> AnyStr: ...
    def getHour(self) -> AnyStr: ...
    def getMinute(self) -> AnyStr: ...
    def getSelectedDays(self) -> AnyStr: ...
    def isAlldays(self) -> bool: ...
    def isDaySelected(self, day: ScheduleModel.DayOfWeek) -> bool: ...
    def isEveryHourEnabled(self) -> bool: ...
    def isEveryMinuteEnabled(self) -> bool: ...
    def isHourEnabled(self) -> bool: ...
    def isMinuteEnabled(self) -> bool: ...
    def selectDayOfWeek(self, day: ScheduleModel.DayOfWeek) -> None: ...
    def setAllDays(self, allDays: bool) -> None: ...
    def setEveryHour(self, everyHour: AnyStr) -> None: ...
    def setHour(self, hour: AnyStr) -> None: ...
    def setHourEnabled(self, hourEnabled: bool) -> None: ...
    def setMinute(self, minute: AnyStr) -> None: ...
    def setMinuteEnabled(self, minuteEnabled: bool) -> None: ...
    def setSelectedDays(self, selectedDays: AnyStr) -> None: ...
    def toCronString(self) -> AnyStr: ...

    class DayOfWeek(Enum):
        @staticmethod
        def values() -> Iterable[ScheduleModel.DayOfWeek]: ...



from typing import Optional

from com.inductiveautomation.ignition.common.opc import BrowseElementType
from com.inductiveautomation.ignition.common.sqltags.model.types import DataType
from com.inductiveautomation.ignition.common.tags.config.types import TagObjectType
from dev.thecesrom.helper.types import AnyStr
from java.lang import Class, Object

class BrowseTag(Object):
    dataType: DataType
    name: AnyStr
    fullPath: AnyStr
    path: AnyStr
    type: TagObjectType
    valueSource: AnyStr
    def __init__(
        self,
        name: str,
        path: str,
        fullPath: str,
        type_: TagObjectType,
        valueSource: str,
        dataType: DataType,
    ) -> None: ...
    def getDataType(self) -> DataType: ...
    def getFullPath(self) -> AnyStr: ...
    def getPath(self) -> AnyStr: ...
    def getTagType(self) -> TagObjectType: ...
    def getValueSource(self) -> AnyStr: ...
    def isDB(self) -> bool: ...
    def isExpression(self) -> bool: ...
    def isFolder(self) -> bool: ...
    def isMemory(self) -> bool: ...
    def isOPC(self) -> bool: ...
    def isQuery(self) -> bool: ...
    def isUDT(self) -> bool: ...

class OPCBrowseTag(Object):
    def __init__(
        self,
        opcServer: Optional[str] = ...,
        type_: Optional[BrowseElementType] = ...,
        displayName: Optional[str] = ...,
        displayPath: Optional[str] = ...,
        dataType: Optional[Class] = ...,
        opcItemPath: Optional[str] = ...,
    ) -> None: ...
    def getDataType(self) -> Optional[Class]: ...
    def getDisplayName(self) -> Optional[str]: ...
    def getDisplayPath(self) -> Optional[str]: ...
    def getOpcItemPath(self) -> Optional[str]: ...
    def getOpcServer(self) -> Optional[str]: ...
    def getType(self) -> Optional[BrowseElementType]: ...



from typing import List, Optional

from com.inductiveautomation.factorypmi.application.script.builtin import PrintUtilities
from dev.thecesrom.helper.types import AnyStr
from java.awt import Component
from java.awt.image import BufferedImage

LANDSCAPE: int
PORTRAIT: int

def createImage(component: Component) -> BufferedImage: ...
def createPrintJob(component: Component) -> PrintUtilities.JythonPrintJob: ...
def getDefaultPrinterName() -> Optional[unicode]: ...
def getPrinterNames() -> List[unicode]: ...
def printToImage(component: Component, filename: Optional[AnyStr] = ...) -> None: ...



from typing import Any, Iterator

from com.inductiveautomation.ignition.common import QualifiedPath, StringPath
from com.inductiveautomation.ignition.common.config import BasicPropertySet
from dev.thecesrom.helper.types import AnyStr
from java.lang import Object
from java.util import UUID
from org.python.core import PyObject

class AlarmEvent:
    def __iter__(self) -> Iterator[Any]: ...
    def acknowledge(self, ackData: EventData) -> None: ...
    def active(self, activeData: EventData) -> None: ...
    def clear(self, clearData: EventData) -> None: ...
    def getAckData(self) -> EventData: ...
    def getActiveData(self) -> EventData: ...
    def getClearedData(self) -> EventData: ...
    def getDisplayPath(self) -> StringPath: ...
    def getDisplayPathOrSource(self) -> AnyStr: ...
    def getId(self) -> UUID: ...
    def getLabel(self) -> AnyStr: ...
    def getLastEventState(self) -> Any: ...
    def getName(self) -> AnyStr: ...
    def getNotes(self) -> AnyStr: ...
    def getPriority(self) -> Any: ...
    def getSource(self) -> QualifiedPath: ...
    def getState(self) -> Any: ...
    def isAcked(self) -> bool: ...
    def isCleared(self) -> bool: ...
    def isShelved(self) -> bool: ...
    def iterator(self) -> Any: ...

class EventData(BasicPropertySet):
    def __init__(self, *args: Any) -> None: ...
    def getTimeStamp(self) -> long: ...

class PyAlarmEvent(AlarmEvent):
    def __iter__(self) -> Iterator[Any]: ...
    def acknowledge(self, ackData: EventData) -> None: ...
    def active(self, activeData: EventData) -> None: ...
    def clear(self, clearData: EventData) -> None: ...
    def contains(self, property: AnyStr) -> bool: ...
    def get(self, property: AnyStr) -> Object: ...
    def getAckData(self) -> EventData: ...
    def getActiveData(self) -> EventData: ...
    def getClearedData(self) -> EventData: ...
    def getDisplayPath(self) -> StringPath: ...
    def getDisplayPathOrSource(self) -> AnyStr: ...
    def getId(self) -> UUID: ...
    def getLabel(self) -> AnyStr: ...
    def getLastEventState(self) -> Any: ...
    def getName(self) -> AnyStr: ...
    def getNotes(self) -> AnyStr: ...
    def getOrDefault(self, property: AnyStr) -> Object: ...
    def getOrElse(self, property: AnyStr, defaultValue: Object) -> Object: ...
    def getPriority(self) -> Any: ...
    def getSource(self) -> QualifiedPath: ...
    def getState(self) -> Any: ...
    def isAcked(self) -> bool: ...
    def isCleared(self) -> bool: ...
    def isShelved(self) -> bool: ...
    def set(self, property: AnyStr, value: Object) -> None: ...
    def setGlobal(self, property: AnyStr, value: Object) -> None: ...
    def sourceEvent(self) -> AlarmEvent: ...

class PyAlarmEventImpl(PyAlarmEvent, PyObject):
    def __init__(self, event: AlarmEvent) -> None: ...
    def contains(self, property: AnyStr) -> bool: ...
    def get(self, property: AnyStr) -> Object: ...
    def getOrDefault(self, property: AnyStr) -> Object: ...
    def getOrElse(self, property: AnyStr, defaultValue: Object) -> Object: ...
    def set(self, property: AnyStr, value: Object) -> None: ...
    def setGlobal(self, property: AnyStr, value: Object) -> None: ...
    def sourceEvent(self) -> AlarmEvent: ...



from typing import Any, Iterable

from java.io import OutputStream
from java.lang import Object

class Snapshot(Object):
    def __init__(self) -> None: ...
    def dump(self, output: OutputStream) -> None: ...
    def get75thPercentile(self) -> float: ...
    def get95thPercentile(self) -> float: ...
    def get98thPercentile(self) -> float: ...
    def get999thPercentile(self) -> float: ...
    def get99thPercentile(self) -> float: ...
    def getMax(self) -> long: ...
    def getMean(self) -> float: ...
    def getMedian(self) -> float: ...
    def getMin(self) -> long: ...
    def getStdDev(self) -> float: ...
    def getValue(self, quantile: float) -> float: ...
    def getValues(self) -> Iterable[long]: ...
    def size(self) -> int: ...

class Timer(Object):
    def __init__(self, *args: Any) -> None: ...
    def getCount(self) -> long: ...
    def getFifteenMinuteRate(self) -> float: ...
    def getFiveMinuteRate(self) -> float: ...
    def getMeanRate(self) -> float: ...
    def getOneMinuteRate(self) -> float: ...
    def getSnapshot(self) -> Snapshot: ...
    def time(self) -> Timer.Context: ...
    def update(self, *args: Any) -> None: ...

    class Context(Object):
        def close(self) -> None: ...
        def stop(self) -> long: ...



from typing import List

from java.lang import Enum

class ResolverStyle(Enum):
    LENIENT: ResolverStyle
    SMART: ResolverStyle
    STRICT: ResolverStyle
    @staticmethod
    def values() -> List[ResolverStyle]: ...



from typing import Any, Dict, List, Optional, Tuple, Union

from com.inductiveautomation.ignition.common.alarming.evaluation import ShelvedPath
from com.inductiveautomation.ignition.common.alarming.query import AlarmQueryResultImpl
from dev.thecesrom.helper.types import AnyStr
from java.util import Date

def acknowledge(
    alarmIds: List[AnyStr], notes: AnyStr, username: Optional[AnyStr] = ...
) -> List[AnyStr]: ...
def cancel(alarmIds: List[AnyStr]) -> None: ...
def createRoster(name: AnyStr, description: AnyStr) -> None: ...
def getRosters() -> Dict[AnyStr, List[AnyStr]]: ...
def getShelvedPaths() -> List[ShelvedPath]: ...
def listPipelines(projectName: AnyStr = ...) -> List[AnyStr]: ...
def queryJournal(
    startDate: Optional[Date] = ...,
    endDate: Optional[Date] = ...,
    journalName: Optional[AnyStr] = ...,
    priority: Optional[List[Union[AnyStr, int]]] = ...,
    state: Optional[List[Union[AnyStr, int]]] = ...,
    path: Optional[List[AnyStr]] = ...,
    source: Optional[List[AnyStr]] = ...,
    displaypath: Optional[List[AnyStr]] = ...,
    all_properties: Optional[List[Tuple[AnyStr, AnyStr, Any]]] = ...,
    any_properties: Optional[List[Tuple[AnyStr, AnyStr, Any]]] = ...,
    defined: Optional[List[AnyStr]] = ...,
    includeData: Optional[bool] = ...,
    includeSystem: Optional[bool] = ...,
    isSystem: Optional[bool] = ...,
) -> AlarmQueryResultImpl: ...
def queryStatus(
    priority: Optional[List[Union[AnyStr, int]]] = ...,
    state: Optional[List[Union[AnyStr, int]]] = ...,
    path: Optional[List[AnyStr]] = ...,
    source: Optional[List[AnyStr]] = ...,
    displaypath: Optional[List[AnyStr]] = ...,
    all_properties: Optional[List[Tuple[AnyStr, AnyStr, Any]]] = ...,
    any_properties: Optional[List[Tuple[AnyStr, AnyStr, Any]]] = ...,
    defined: Optional[List[AnyStr]] = ...,
    includeShelved: bool = ...,
) -> AlarmQueryResultImpl: ...
def shelve(
    path: List[AnyStr], timeoutSeconds: int = ..., timeoutMinutes: int = ...
) -> None: ...
def unshelve(path: List[AnyStr]) -> None: ...



from typing import Any, List

from com.inductiveautomation.ignition.common.browsing import Results
from com.inductiveautomation.ignition.common.model.values import QualityCode
from com.inductiveautomation.ignition.common.sqltags.history import AggregateInfo
from com.inductiveautomation.opccom.hda import AttributeInfo, ReadResult
from dev.thecesrom.helper.types import AnyStr
from java.util import Date

def browse(root: AnyStr) -> List[Results]: ...
def getAggregates(serverName: AnyStr) -> List[AggregateInfo]: ...
def getAttributes(serverName: AnyStr) -> List[AttributeInfo]: ...
def getServers() -> List[AnyStr]: ...
def insert(
    serverName: AnyStr, itemId: AnyStr, value: Any, date: Any, quality: int
) -> QualityCode: ...
def insertReplace(
    serverName: AnyStr, itemId: AnyStr, value: Any, date: Date, quality: int
) -> QualityCode: ...
def isServerAvailable(serverName: AnyStr) -> bool: ...
def readAttributes(
    serverName: AnyStr,
    itemId: AnyStr,
    attributeIds: List[AnyStr],
    startDate: Date,
    endDate: Date,
) -> List[ReadResult]: ...
def readProcessed(
    serverName: AnyStr,
    itemIds: List[AnyStr],
    startDate: Date,
    endDate: Date,
    resampleIntervalMS: int,
    aggregates: List[Any],
) -> List[ReadResult]: ...
def readRaw(
    serverName: AnyStr,
    itemIds: List[AnyStr],
    startDate: Date,
    endDate: Date,
    maxValues: int,
    boundingValues: bool,
) -> List[Any]: ...
def replace(
    serverName: AnyStr, itemId: AnyStr, value: Any, date: Date, quality: int
) -> QualityCode: ...



from typing import Any, List, Optional

from dev.thecesrom.helper.types import AnyStr
from java.lang import Class, Enum, Object, StringBuilder

class OPCBrowseElement:
    def getDataType(self) -> Class: ...
    def getDescription(self) -> AnyStr: ...
    def getDisplayName(self) -> AnyStr: ...
    def getElementType(self) -> BrowseElementType: ...
    def getNodeId(self) -> AnyStr: ...
    def getServerNodeId(self) -> ServerNodeId: ...

class ServerNodeId:
    def getNodeId(self) -> AnyStr: ...
    def getServerName(self) -> AnyStr: ...

class BasicOPCBrowseElement(Object, OPCBrowseElement):
    def __init__(self, *args: Any) -> None: ...
    def getDataType(self) -> Class: ...
    def getDescription(self) -> AnyStr: ...
    def getDisplayName(self) -> AnyStr: ...
    def getElementType(self) -> BrowseElementType: ...
    def getNodeId(self) -> AnyStr: ...
    def getServerNodeId(self) -> ServerNodeId: ...

class BasicServerNodeId(Object, ServerNodeId):
    nodeId: AnyStr
    serverName: AnyStr
    def __init__(self, serverName: AnyStr, nodeId: AnyStr) -> None: ...
    def getNodeId(self) -> AnyStr: ...
    def getServerName(self) -> AnyStr: ...

class BrowseElement(Object):
    PROP_PROVIDER: int
    PROP_DRIVER: int
    def __init__(self, itemType: Optional[int] = ...) -> None: ...
    def addProperty(self, id_: int, name: AnyStr, value: AnyStr) -> None: ...
    def asServerNodeId(self) -> ServerNodeId: ...
    def createRequestElement(self, type_: int) -> BrowseElement: ...
    def fillInDetails(self, elm: BrowseElement) -> None: ...
    def getBrowsePath(self) -> AnyStr: ...
    def getItemId(self) -> AnyStr: ...
    def getItemName(self) -> AnyStr: ...
    def getItemType(self) -> Optional[int]: ...
    def getProperties(self) -> List[BrowseElement.PropertyElement]: ...
    def getProperty(self, id_: int) -> BrowseElement.PropertyElement: ...
    def getServer(self) -> AnyStr: ...
    def isComplete(self) -> bool: ...
    def setBrowsePath(self, browsePath: AnyStr) -> None: ...
    def setComplete(self, value: bool) -> None: ...
    def setItemId(self, itemId: AnyStr) -> None: ...
    def setItemName(self, itemName: AnyStr) -> None: ...
    def setItemType(self, itemType: int) -> None: ...
    def setServer(self, server: AnyStr) -> None: ...
    @staticmethod
    def toBrowseElement(opcElem: OPCBrowseElement) -> BrowseElement: ...
    @staticmethod
    def toBrowseElements(
        opcElements: List[OPCBrowseElement],
    ) -> List[BrowseElement]: ...
    @staticmethod
    def toServerNodeId(elem: BrowseElement) -> ServerNodeId: ...
    def toXML(
        self,
        out: StringBuilder,
        type_: Optional[int] = ...,
        includeProperties: Optional[bool] = ...,
    ) -> None: ...

    class PropertyElement(Object):
        id: int
        name: AnyStr
        value: AnyStr
        def __init__(self, id_: int, name: AnyStr, value: AnyStr) -> None: ...
        def getId(self) -> int: ...
        def getName(self) -> AnyStr: ...
        def getValue(self) -> AnyStr: ...

class BrowseElementType(Enum):
    DATAVARIABLE: BrowseElementType
    DEVICE: BrowseElementType
    FOLDER: BrowseElementType
    METHOD: BrowseElementType
    OBJECT: BrowseElementType
    PROPERTY: BrowseElementType
    SERVER: BrowseElementType
    VIEW: BrowseElementType
    def isSubscribable(self) -> bool: ...
    @staticmethod
    def values() -> List[BrowseElementType]: ...

class ServerBrowseElement(Object, OPCBrowseElement):
    nodeId: ServerNodeId
    def __init__(self, serverName: AnyStr) -> None: ...
    def getDataType(self) -> Class: ...
    def getDescription(self) -> AnyStr: ...
    def getDisplayName(self) -> AnyStr: ...
    def getElementType(self) -> BrowseElementType: ...
    def getNodeId(self) -> AnyStr: ...
    def getServerNodeId(self) -> ServerNodeId: ...



from typing import List

from com.inductiveautomation.ignition.common.user import User
from com.palantir.ptoss.cinch.core import DefaultBindableModel
from dev.thecesrom.helper.types import AnyStr

class RosterModel(DefaultBindableModel):
    def __init__(self) -> None: ...
    def getName(self) -> AnyStr: ...
    def getUsers(self) -> List[AnyStr]: ...
    def set(self, that: RosterModel) -> None: ...
    def setName(self, name: AnyStr) -> None: ...
    def setUsers(self, users: List[User]) -> None: ...



from com.inductiveautomation.factorypmi.application import VisionDesktop
from com.inductiveautomation.factorypmi.application.model import TemplateManager
from com.inductiveautomation.factorypmi.application.script.builtin import (
    ClientDatasetUtilities,
    ClientSystemUtilities,
    NavUtilities,
    WindowUtilities,
)
from com.inductiveautomation.factorypmi.application.sqltags.project import (
    ProjectTagManager,
)

class VisionClientContext:
    def getDatasetUtil(self) -> ClientDatasetUtilities: ...
    def getGuiUtil(self) -> WindowUtilities: ...
    def getNavUtil(self) -> NavUtilities: ...
    def getPrimaryDesktop(self) -> VisionDesktop: ...
    def getProjectTags(self) -> ProjectTagManager: ...
    def getSystemUtil(self) -> ClientSystemUtilities: ...
    def getTemplateManager(self) -> TemplateManager: ...
    def getUpdateBase(self) -> int: ...



from typing import Any, Mapping, Optional, Union

from com.google.common.collect import ImmutableSet
from com.inductiveautomation.ignition.common import StringPath
from com.inductiveautomation.ignition.common.gson import (
    JsonDeserializationContext,
    JsonElement,
    JsonObject,
    JsonSerializationContext,
)
from dev.thecesrom.helper.types import AnyStr
from java.lang import Comparable, Object
from java.lang.reflect import Type
from java.util.function import Consumer

class ProjectResource:
    @staticmethod
    def calculateContentDigest(resource: ProjectResource) -> bytearray: ...
    def copy(self, consumer: Optional[Consumer] = ...) -> ProjectResource: ...
    def getApplicationScope(self) -> int: ...
    def getAttribute(self, key: AnyStr) -> JsonElement: ...
    def getAttributes(self) -> Mapping[AnyStr, JsonElement]: ...
    def getContentDigest(self) -> bytearray: ...
    def getData(self) -> bytearray: ...
    def getDataKeys(self) -> ImmutableSet: ...
    def getDocumentation(self) -> AnyStr: ...
    def getFolderPath(self) -> AnyStr: ...
    def getProjectName(self) -> AnyStr: ...
    def getResourceId(self) -> ProjectResourceId: ...
    def getResourceName(self) -> AnyStr: ...
    def getResourcePath(self) -> ResourcePath: ...
    def getResourceSignature(self) -> ResourceSignature: ...
    def getResourceType(self) -> ResourceType: ...
    def getVersion(self) -> int: ...
    def isFolder(self) -> bool: ...
    def isLocked(self) -> bool: ...
    def isModuleFolder(self) -> bool: ...
    def isOverridable(self) -> bool: ...
    def isResourceTypeFolder(self) -> bool: ...
    def isRestricted(self) -> bool: ...
    def isSingletonResource(self) -> bool: ...
    @staticmethod
    def newBuilder() -> ProjectResourceBuilder: ...
    def toBuilder(self) -> ProjectResourceBuilder: ...

class ProjectResourceBuilder(Object):
    def build(self) -> ProjectResource: ...
    def clearAttributes(self) -> ProjectResourceBuilder: ...
    def clearData(self) -> ProjectResourceBuilder: ...
    def copyFrom(self, resource: ProjectResource) -> ProjectResourceBuilder: ...
    def putAttribute(self, key: AnyStr, value: Any) -> ProjectResourceBuilder: ...
    def putData(self, *args: Any) -> ProjectResourceBuilder: ...
    def removeAttribute(self, key: AnyStr) -> ProjectResourceBuilder: ...
    def removeData(self, name: AnyStr) -> ProjectResourceBuilder: ...
    def setApplicationScope(
        self, scope: Union[AnyStr, int]
    ) -> ProjectResourceBuilder: ...
    def setAttributes(
        self, attributes: Mapping[AnyStr, JsonElement]
    ) -> ProjectResourceBuilder: ...
    def setData(self, data: Mapping[AnyStr, bytearray]) -> ProjectResourceBuilder: ...
    def setDocumentation(self, documentation: AnyStr) -> ProjectResourceBuilder: ...
    def setFolder(self, folder: bool) -> ProjectResourceBuilder: ...
    def setLocked(self, locked: bool) -> ProjectResourceBuilder: ...
    def setOverridable(self, overridable: bool) -> ProjectResourceBuilder: ...
    def setProjectName(self, projectName: AnyStr) -> ProjectResourceBuilder: ...
    def setResourceId(self, id_: ProjectResourceId) -> ProjectResourceBuilder: ...
    def setResourcePath(self, resourcePath: ResourcePath) -> ProjectResourceBuilder: ...
    def setRestricted(self, restricted: bool) -> ProjectResourceBuilder: ...
    def setVersion(self, version: int) -> ProjectResourceBuilder: ...

class ProjectResourceId(Object):
    def __init__(self, *args: Any) -> None: ...
    @staticmethod
    def fromJson(e: JsonElement) -> ProjectResourceId: ...
    def getFolderPath(self) -> AnyStr: ...
    def getProjectName(self) -> AnyStr: ...
    def getResourcePath(self) -> ResourcePath: ...
    def getResourceType(self) -> ResourceType: ...
    def toJson(self) -> JsonObject: ...

class ResourcePath(Object, Comparable):
    def __init__(
        self, type_: ResourceType, path: Union[AnyStr, StringPath]
    ) -> None: ...
    def compareTo(self, o: Any) -> int: ...
    @staticmethod
    def createModuleRoot(moduleId: AnyStr) -> ResourcePath: ...
    def getChild(self, *pathParts: AnyStr) -> ResourcePath: ...
    def getFolderPath(self) -> AnyStr: ...
    def getModuleId(self) -> AnyStr: ...
    def getName(self) -> AnyStr: ...
    def getParent(self) -> ResourcePath: ...
    def getParentPath(self) -> AnyStr: ...
    def getPath(self) -> StringPath.CaseSensitiveStringPath: ...
    def getResourceType(self) -> ResourceType: ...
    def getType(self) -> ResourceType: ...
    def isAncestorOf(self, possibleDescendant: ResourcePath) -> bool: ...
    def isParentOf(self, possibleChild: ResourcePath) -> bool: ...
    def isResourceTypeFolder(self) -> bool: ...

class ResourceSignature(Object):
    def __init__(self, resourceId: ProjectResourceId, signature: bytearray) -> None: ...
    def getResourceId(self) -> ProjectResourceId: ...
    def getSignature(self) -> bytearray: ...

    class GsonAdapter(Object):
        def deserialize(
            self, json: JsonElement, typeOfT: Type, context: JsonDeserializationContext
        ) -> ResourceSignature: ...
        def serialize(
            self,
            src: ResourceSignature,
            typeOfSrc: Type,
            context: JsonSerializationContext,
        ) -> JsonElement: ...

class ResourceType(Object):
    def __init__(self, moduleId: AnyStr, typeId: AnyStr) -> None: ...
    def childOrSubPath(
        self, potentialFolder: ResourcePath, path: AnyStr
    ) -> ResourcePath: ...
    def getModuleId(self) -> AnyStr: ...
    def getTypeId(self) -> AnyStr: ...
    def matches(self, op: Any) -> bool: ...
    def rootPath(self) -> ResourcePath: ...
    def subPath(self, path: AnyStr) -> ResourcePath: ...



from dev.thecesrom.helper.types import AnyStr
from java.lang import Object
from javax.security.auth import Subject

class Principal:
    def equals(self, another: Object) -> bool: ...
    def getName(self) -> AnyStr: ...
    def hashCode(self) -> int: ...
    def implies(self, subject: Subject) -> bool: ...
    def toString(self) -> AnyStr: ...



from dev.thecesrom.helper.types import AnyStr
from java.lang import Object
from org.python.core import PyObject

class PyComponentWrapper(PyObject):
    def __init__(self, component: Object) -> None: ...
    def wrapMethod(self, name: AnyStr) -> PyObject: ...



from typing import Any, List, Mapping, Optional, Set

from dev.thecesrom.helper.types import AnyStr
from java.io import Closeable, InputStream, OutputStream
from java.lang import Class, Enum, Object
from java.nio.channels import SocketChannel

class SocketAddress(Object):
    def __init__(self) -> None: ...

class CookiePolicy:
    def shouldAccept(self, uri: URI, cookie: HttpCookie) -> bool: ...

class CookieStore:
    def add(self, uri: URI, cookie: HttpCookie) -> None: ...
    def get(self, uri: URI) -> List[HttpCookie]: ...
    def getCookies(self) -> List[HttpCookie]: ...
    def getURIs(self) -> List[URI]: ...
    def remove(self, uri: URI, cookie: HttpCookie) -> bool: ...
    def removeAll(self) -> bool: ...

class FileNameMap:
    def getContentTypeFor(self, fileName: AnyStr) -> AnyStr: ...

class SocketImplFactory:
    def createSocketImpl(self) -> SocketImpl: ...

class SocketOption:
    def name(self) -> AnyStr: ...
    def type(self) -> Class: ...

class CookieHandler(Object):
    def __init__(self) -> None: ...
    def get(
        self, uri: URI, requestHeaders: Mapping[AnyStr, List[AnyStr]]
    ) -> Mapping[AnyStr, List[AnyStr]]: ...
    @staticmethod
    def getDefault() -> CookieHandler: ...
    def put(
        self, uri: URI, responseHeaders: Mapping[AnyStr, List[AnyStr]]
    ) -> Mapping[AnyStr, List[AnyStr]]: ...
    @staticmethod
    def setDefault(cHandler: CookieHandler) -> None: ...

class CookieManager(CookieHandler):
    def __init__(self, *args: Any) -> None: ...
    def get(
        self, uri: URI, requestHeaders: Mapping[AnyStr, List[AnyStr]]
    ) -> Mapping[AnyStr, List[AnyStr]]: ...
    def getCookieStore(self) -> CookieStore: ...
    def put(
        self, uri: URI, responseHeaders: Mapping[AnyStr, List[AnyStr]]
    ) -> Mapping[AnyStr, List[AnyStr]]: ...
    def setCookiePolicy(self, cookiePolicy: CookiePolicy) -> None: ...

class HttpCookie(Object):
    def __init__(self, name: AnyStr, value: AnyStr) -> None: ...

class InetAddress(Object):
    def getAddress(self) -> bytearray: ...
    @staticmethod
    def getAllByName(host: AnyStr) -> List[InetAddress]: ...
    @staticmethod
    def getByAddress(*args: Any) -> InetAddress: ...
    @staticmethod
    def getByName(host: AnyStr) -> InetAddress: ...
    def getCanonicalHostName(self) -> AnyStr: ...
    def getHostAddress(self) -> AnyStr: ...
    def getHostName(self) -> AnyStr: ...
    @staticmethod
    def getLocalHost() -> InetAddress: ...
    @staticmethod
    def getLoopbackAddress() -> InetAddress: ...
    def isAnyLocalAddress(self) -> bool: ...
    def isLinkLocalAddress(self) -> bool: ...
    def isLoopbackAddress(self) -> bool: ...
    def isMCGlobal(self) -> bool: ...
    def isMCLinkLocal(self) -> bool: ...
    def isMCNodeLocal(self) -> bool: ...
    def isMCOrgLocal(self) -> bool: ...
    def isMCSiteLocal(self) -> bool: ...
    def isMulticastAddress(self) -> bool: ...
    def isReachable(self, *args: Any) -> bool: ...
    def isSiteLocalAddress(self) -> bool: ...

class InetSocketAddress(SocketAddress):
    def __init__(self, *args: Any) -> None: ...
    @staticmethod
    def createUnresolved(host: AnyStr, port: int) -> InetSocketAddress: ...
    def getAddress(self) -> InetAddress: ...
    def getHostname(self) -> AnyStr: ...
    def getHostString(self) -> AnyStr: ...
    def getPort(self) -> int: ...
    def isUnresolved(self) -> bool: ...

class Proxy(Object):
    NO_PROXY: Proxy
    def __init__(self, type_: Proxy.Type, sa: SocketAddress) -> None: ...
    def address(self) -> SocketAddress: ...
    def type(self) -> Proxy.Type: ...

    class Type(Enum):
        DIRECT: Proxy.Type
        HTTP: Proxy.Type
        SOCKS: Proxy.Type
        @staticmethod
        def values() -> List[Proxy.Type]: ...

class Socket(Object, Closeable):
    def __init__(self, *args: Any) -> None: ...
    def bind(self, bindpoint: SocketAddress) -> None: ...
    def close(self) -> None: ...
    def connect(
        self, endpoint: SocketAddress, timeout: Optional[int] = ...
    ) -> None: ...
    def getChannel(self) -> SocketChannel: ...
    def getInetAddress(self) -> InetAddress: ...
    def getInputStream(self) -> InputStream: ...
    def getKeepAlive(self) -> bool: ...
    def getLocalAddress(self) -> InetAddress: ...
    def getLocalPort(self) -> int: ...
    def getLocalSocketAddress(self) -> SocketAddress: ...
    def getOOBInline(self) -> bool: ...
    def getOption(self, name: SocketOption) -> Any: ...
    def getOutputStream(self) -> OutputStream: ...
    def getPort(self) -> int: ...
    def getReceiveBufferSize(self) -> int: ...
    def getRemoteSocketAddress(self) -> SocketAddress: ...
    def getReuseAddress(self) -> bool: ...
    def getSendBufferSize(self) -> int: ...
    def getSoLinger(self) -> int: ...
    def getSoTimeout(self) -> int: ...
    def getTcpNoDelay(self) -> bool: ...
    def getTrafficClass(self) -> int: ...
    def isBound(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isConnected(self) -> bool: ...
    def isInputShutdown(self) -> bool: ...
    def isOutputShutdown(self) -> bool: ...
    def sendUrgentData(self, data: int) -> None: ...
    def setKeepAlive(self, on: bool) -> None: ...
    def setOOBInline(self, on: bool) -> None: ...
    def setOption(self, name: SocketOption, value: Any) -> Socket: ...
    def setPerformancePreferences(
        self, connectionTime: int, latency: int, bandwidth: int
    ) -> None: ...
    def setReceiveBufferSize(self, size: int) -> None: ...
    def setReuseAddress(self, on: bool) -> None: ...
    def setSendBufferSize(self, size: int) -> None: ...
    @staticmethod
    def setSocketImplFactory(fac: SocketImplFactory) -> None: ...
    def setSoLinger(self, on: bool, linger: int) -> None: ...
    def setSoTimeout(self, timeout: int) -> None: ...
    def setTcpNoDelay(self, on: bool) -> None: ...
    def setTrafficClass(self, tc: int) -> None: ...
    def shutdownInput(self) -> None: ...
    def shutdownOutput(self) -> None: ...
    def supportedOptions(self) -> Set[SocketOption]: ...

class SocketImpl(Object):
    def __init__(self) -> None: ...

class URI(Object):
    def __init__(self, *args: Any) -> None: ...



from typing import Any, List, Optional

from dev.thecesrom.helper.types import AnyStr
from system.bacnet.enumerated import ObjectType, PropertyIdentifier

def readRaw(
    deviceName: AnyStr,
    objectType: ObjectType,
    objectId: int,
    propertyId: PropertyIdentifier,
    propertyArrayIndex: Optional[int] = ...,
) -> List[Any]: ...
def synchronizeTime(deviceName: AnyStr) -> None: ...
def synchronizeTimeUtc(deviceName: AnyStr) -> None: ...
def writeRaw(
    deviceName: AnyStr,
    objectType: ObjectType,
    objectId: int,
    propertyId: PropertyIdentifier,
    value: Any,
    priority: int,
    propertyArrayIndex: int,
) -> None: ...
def writeWithPriority(
    deviceName: AnyStr, objectType: int, objectId: int, value: Any, priority: int
) -> None: ...

# Names in __all__ with no definition:
#   enumerated
#   enums



from typing import Any, Optional, Union

from dev.thecesrom.helper.types import AnyStr
from java.lang import (
    Appendable,
    AutoCloseable,
    CharSequence,
    Exception,
    Object,
    Throwable,
)

class Closeable(AutoCloseable):
    def close(self) -> None: ...

class Flushable:
    def flush(self) -> None: ...

class File(Object):
    pathSeparator: AnyStr
    pathSeparatorChar: AnyStr
    separator: AnyStr
    separatorChar: AnyStr
    def __init__(self, *args: Any) -> None: ...

class FileDescriptor(Object):
    def sync(self) -> None: ...
    def valid(self) -> bool: ...

class OutputStream(Object, Closeable, Flushable):
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @staticmethod
    def nullOutputStream() -> OutputStream: ...
    def write(self, *args: Any) -> None: ...

class FileOutputStream(OutputStream):
    def __init__(self, *args: Any) -> None: ...
    def getChannel(self) -> Any: ...
    def getFD(self) -> FileDescriptor: ...

class FilterOutputStream(OutputStream):
    def __init__(self, out: OutputStream) -> None: ...

class DataOutputStream(FilterOutputStream):
    out: OutputStream
    def __init__(self, out: OutputStream) -> None: ...
    def size(self) -> int: ...
    def writeBoolean(self, v: bool) -> None: ...
    def writeByte(self, v: int) -> None: ...
    def writeBytes(self, s: AnyStr) -> None: ...
    def writeChar(self, v: int) -> None: ...
    def writeChars(self, s: AnyStr) -> None: ...
    def writeDouble(self, v: float) -> None: ...
    def writeFloat(self, v: float) -> None: ...
    def writeInt(self, v: int) -> None: ...
    def writeLong(self, v: long) -> None: ...
    def writeShort(self, v: int) -> None: ...
    def writeUTF(self, s: AnyStr) -> None: ...

class PrintStream(FilterOutputStream):
    def __init__(self, *args: Any) -> None: ...
    def append(self, *args: Any) -> PrintStream: ...
    def checkError(self) -> bool: ...
    def format(self, *args: Any) -> PrintStream: ...
    def print(self, arg: Any) -> None: ...
    def printf(self, *args: Any) -> None: ...
    def println(self, arg: Any) -> None: ...

class InputStream(Object, Closeable):
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readlimit: int) -> None: ...
    def markSupported(self) -> bool: ...
    @staticmethod
    def nullInputStream() -> InputStream: ...
    def read(self, *args: Any) -> int: ...
    def readAllBytes(self) -> bytearray: ...
    def readNBytes(self, *args: Any) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: long) -> long: ...
    def transferTo(self, out: OutputStream) -> long: ...

class IOException(Exception):
    def __init__(
        self, message: Optional[str] = ..., cause: Optional[Throwable] = ...
    ) -> None: ...

class Reader(Object, AutoCloseable):
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int) -> None: ...
    def markSupported(self) -> bool: ...
    @staticmethod
    def nullReader() -> Reader: ...
    def read(self, *args: Any) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: long) -> long: ...
    def transferTo(self, out: Writer) -> long: ...

class BufferedReader(Reader):
    def __init__(self, in_: Reader, sz: Optional[int] = ...) -> None: ...
    def close(self) -> None: ...

class Writer(Object, Appendable, Closeable, Flushable):
    def append(
        self, c_csq: Union[CharSequence, str], start: int = ..., end: int = ...
    ) -> Writer: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @staticmethod
    def nullWriter() -> Writer: ...
    def write(self, *args: Any) -> None: ...

class BufferedWriter(Writer):
    def __init__(self, out: Writer, sz: Optional[int] = ...) -> None: ...

class PrintWriter(Writer):
    def __init__(self, *args: Any) -> None: ...
    def append(
        self, c_csq: Union[CharSequence, str], start: int = ..., end: int = ...
    ) -> PrintWriter: ...
    def checkError(self) -> bool: ...
    def format(self, *args: Any) -> PrintWriter: ...
    def print(self, arg: Any) -> None: ...
    def printf(self, *args: Any) -> PrintWriter: ...
    def println(self, arg: Any) -> None: ...
    def write(self, *args: Any) -> None: ...



from typing import List

from com.inductiveautomation.ignition.common import BasicDataset
from dev.thecesrom.helper.types import AnyStr

def getAccounts() -> List[AnyStr]: ...
def getAccountsDataset() -> BasicDataset: ...
def getPhoneNumbers(accountName: AnyStr) -> List[AnyStr]: ...
def getPhoneNumbersDataset(accountName: AnyStr) -> BasicDataset: ...
def sendSms(
    accountName: AnyStr, fromNumber: AnyStr, toNumber: AnyStr, message: AnyStr
) -> None: ...



from typing import Any, Optional, Union

from dev.thecesrom.helper.types import AnyStr
from java.lang import Runnable
from java.util.concurrent import ScheduledFuture, TimeUnit

class ExecutionManager:
    def executeOnce(
        self,
        command: Runnable,
        delay: Optional[long] = ...,
        unit: Optional[TimeUnit] = ...,
    ) -> Union[None, ScheduledFuture]: ...
    def register(self, *args: Any) -> None: ...
    def registerAtFixedRate(
        self, owner: AnyStr, name: AnyStr, command: Runnable, rate: int, unit: TimeUnit
    ) -> None: ...
    def registerAtFixedRateWithInitialDelay(
        self,
        owner: AnyStr,
        name: AnyStr,
        command: Runnable,
        rate: int,
        unit: TimeUnit,
        initialDelay: int,
    ) -> None: ...
    def registerWithInitialDelay(self, *args: Any) -> None: ...
    def scheduleWithFixedDelay(
        self, command: Runnable, initialDelay: int, delay: int, unit: TimeUnit
    ) -> ScheduledFuture: ...
    def shutdown(self) -> None: ...
    def unregister(self, owner: AnyStr, name: AnyStr, interrupt: bool) -> None: ...
    def unregisterAll(self, owner: AnyStr) -> None: ...



from typing import Mapping

from dev.thecesrom.helper.types import AnyStr

class ScriptFunctionHint:
    def getAutocompleteText(self) -> AnyStr: ...
    def getMethodDescription(self) -> AnyStr: ...
    def getMethodSignature(self) -> AnyStr: ...
    def getParameterDescriptions(self) -> Mapping[AnyStr, AnyStr]: ...
    def getReturnValueDescription(self) -> AnyStr: ...



from typing import Any, Optional

from com.inductiveautomation.ignition.common.gson import Gson
from dev.thecesrom.helper.types import AnyStr
from java.lang import Object
from java.net import CookieManager as JCookieManager
from java.net.http import HttpClient, HttpResponse
from java.nio.charset import Charset
from java.util.concurrent import CompletableFuture
from org.python.core import PyObject

class CookieManager(JCookieManager):
    def __init__(self, *args: Any) -> None: ...

class JythonHttpClient(Object):
    def delete(self, *args: PyObject, **kwargs: AnyStr) -> Response: ...
    def deleteAsync(self, *args: PyObject, **kwargs: AnyStr) -> Promise: ...
    def get(self, *args: PyObject, **kwargs: AnyStr) -> Response: ...
    def getAsync(self, *args: PyObject, **kwargs: AnyStr) -> Promise: ...
    def getConnectTimeout(self) -> long: ...
    def getCookieManager(self) -> CookieManager: ...
    def getJavaClient(self) -> HttpClient: ...
    def getRedirectPolicy(self) -> AnyStr: ...
    def getVersion(self) -> AnyStr: ...
    def head(self, *args: PyObject, **kwargs: AnyStr) -> Response: ...
    def headAsync(self, *args: PyObject, **kwargs: AnyStr) -> Promise: ...
    def options(self, *args: PyObject, **kwargs: AnyStr) -> Response: ...
    def optionsAsync(self, *args: PyObject, **kwargs: AnyStr) -> Promise: ...
    def parseChart(self, contentType: AnyStr) -> Optional[Charset]: ...
    def patch(self, *args: PyObject, **kwargs: AnyStr) -> Response: ...
    def patchAsync(self, *args: PyObject, **kwargs: AnyStr) -> Promise: ...
    def post(self, *args: PyObject, **kwargs: AnyStr) -> Response: ...
    def postAsync(self, *args: PyObject, **kwargs: AnyStr) -> Promise: ...
    def put(self, *args: PyObject, **kwargs: AnyStr) -> Response: ...
    def putAsync(self, *args: PyObject, **kwargs: AnyStr) -> Promise: ...
    def request(self, *args: PyObject, **kwargs: AnyStr) -> Response: ...
    def requestAsync(self, *args: PyObject, **kwargs: AnyStr) -> Promise: ...
    def setGson(self, gson: Gson) -> None: ...
    def trace(self, *args: PyObject, **kwargs: AnyStr) -> Response: ...
    def traceAsync(self, *args: PyObject, **kwargs: AnyStr) -> Promise: ...

class Promise(Object):
    def cancel(self) -> bool: ...
    def get(self, *args: PyObject, **kwargs: AnyStr) -> Any: ...
    def getFuture(self) -> CompletableFuture: ...
    def handleException(self, callback: PyObject) -> Promise: ...
    def isDone(self) -> bool: ...
    def then(self, callback: PyObject) -> Promise: ...
    def whenComplete(self, callback: PyObject) -> None: ...

class Response(Object):
    def __init__(self, httResponse: HttpResponse, client: JythonHttpClient) -> None: ...



from typing import Any, Iterable

from com.inductiveautomation.ignition.common.binding import InteractionListener
from com.inductiveautomation.ignition.common.model.values import QualifiedValue
from java.lang import Class

class Function:
    def connect(self, context: Any, updateListener: InteractionListener) -> None: ...
    def copy(self) -> Function: ...
    def disconnect(self) -> None: ...
    def execute(self, args: Iterable[Any]) -> QualifiedValue: ...
    def getArgDocString(self) -> None: ...
    def getType(self) -> Class: ...
    def initArgs(self, args: Iterable[Any]) -> None: ...
    def shutdown(self) -> None: ...
    def startup(self) -> None: ...



from dev.thecesrom.helper.types import AnyStr
from java.awt import Container

class JTextComponent(Container):
    def getText(self, *args: int) -> AnyStr: ...
    def setText(self, t: AnyStr) -> None: ...



from typing import Any, Iterable, List, Mapping, Optional, Union

from dev.thecesrom.helper.types import AnyStr
from java.awt import Dimension, Image
from java.io import File, InputStream, OutputStream, PrintWriter, Writer
from java.lang import Enum, Object
from javax.swing import JComponent, JPanel, RootPaneContainer

class LaunchContext:
    def getAttribute(self, key: AnyStr, defaultValue: Optional[Any] = ...) -> Any: ...
    def getAttributes(self) -> Mapping[AnyStr, Object]: ...
    def getCacheDir(self) -> File: ...
    def getEdgeFlags(self) -> List[AnyStr]: ...
    def getGatewayAddress(self) -> GatewayAddress: ...
    def getGatewayAddresses(self) -> List[GatewayAddress]: ...
    def getGwCacheDir(self) -> File: ...
    def getLaunchManifest(self) -> LaunchManifest: ...
    def getLog(self) -> PrintWriter: ...
    def getMainClass(self) -> AnyStr: ...
    def getParent(self) -> LaunchParent: ...
    def getPlatformEdition(self) -> AnyStr: ...
    def getProjectCacheChkFile(self) -> File: ...
    def getProjectCacheFile(self) -> File: ...
    def getProjectName(self) -> AnyStr: ...
    def getResourceDir(self) -> File: ...
    def getScopeCode(self) -> AnyStr: ...
    def getTranslationDBLocation(self) -> File: ...
    def getUserObject(self) -> bytearray: ...
    def log(self, message: AnyStr, *args: Object) -> None: ...
    def setAttribute(self, key: AnyStr, value: Object) -> None: ...
    def updateGatewayAddressListCache(self, addrs: List[GatewayAddress]) -> None: ...
    def updateProjectCache(self, project: LaunchContext.WritableProject) -> None: ...

    class WritableProject:
        def write(self, stream: OutputStream) -> None: ...

class LaunchParent:
    def getLaunchFlavor(self) -> LaunchParent.LaunchFlavor: ...
    def getRootPaneContainer(self) -> RootPaneContainer: ...
    def isFullScreen(self) -> bool: ...
    def restart(
        self,
        addresses: List[GatewayAddress],
        projectName: AnyStr,
        scope: AnyStr,
        userObj: bytearray,
    ) -> None: ...
    def setContent(self, context: LaunchContext, app: LaunchableApp) -> None: ...

    class LaunchFlavor(Enum):
        @staticmethod
        def values() -> Iterable[LaunchParent.LaunchFlavor]: ...

class GatewayAddress(Object):
    def __init__(
        self, protocol: AnyStr, address: AnyStr, port: int, path: AnyStr
    ) -> None: ...
    def getAddress(self) -> AnyStr: ...
    def getPath(self) -> AnyStr: ...
    def getPort(self) -> int: ...
    def getProcotol(self) -> AnyStr: ...
    @staticmethod
    def parse(addr: AnyStr) -> GatewayAddress: ...
    def toParseableString(self) -> AnyStr: ...

class LaunchContextImpl(Object, LaunchContext):
    def getAttribute(self, key: AnyStr, defaultValue: Optional[Any] = ...) -> Any: ...
    def getAttributes(self) -> Mapping[AnyStr, Object]: ...
    def getCacheDir(self) -> File: ...
    def getEdgeFlags(self) -> List[AnyStr]: ...
    def getGatewayAddress(self) -> GatewayAddress: ...
    def getGatewayAddresses(self) -> List[GatewayAddress]: ...
    def getGwCacheDir(self) -> File: ...
    def getLaunchManifest(self) -> LaunchManifest: ...
    def getLog(self) -> PrintWriter: ...
    def getMainClass(self) -> AnyStr: ...
    def getParent(self) -> LaunchParent: ...
    def getPlatformEdition(self) -> AnyStr: ...
    def getProjectCacheChkFile(self) -> File: ...
    def getProjectCacheFile(self) -> File: ...
    def getProjectName(self) -> AnyStr: ...
    def getResourceDir(self) -> File: ...
    def getScopeCode(self) -> AnyStr: ...
    def getTranslationDBLocation(self) -> File: ...
    def getUserObject(self) -> bytearray: ...
    def log(self, message: AnyStr, *args: Object) -> None: ...
    def setAttribute(self, key: AnyStr, value: Object) -> None: ...
    def updateGatewayAddressListCache(self, addrs: List[GatewayAddress]) -> None: ...
    def updateProjectCache(self, project: LaunchContext.WritableProject) -> None: ...

class LaunchManifest(Object):
    def __init__(self, *args: Any) -> None: ...
    def addModule(self, module: LaunchManifest.Module) -> None: ...
    def getFrameworkVersion(self) -> int: ...
    def getJavaExecutable(self) -> AnyStr: ...
    def getJreVersion(self) -> AnyStr: ...
    def getModules(self) -> Iterable[LaunchManifest.Module]: ...
    def getPort(self) -> int: ...
    def getScope(self) -> AnyStr: ...
    def getThirdPartyScriptModulesHash(self) -> AnyStr: ...
    def isEmpty(self) -> bool: ...
    def isUseSsl(self) -> bool: ...
    def newDiffAction(self, context: LaunchContextImpl) -> Any: ...
    @staticmethod
    def readFrom(is_: InputStream) -> LaunchManifest: ...
    def setJavaExecutable(self, javaExecutable: AnyStr) -> None: ...
    def setUseCondensedDialogFont(self, useCondensedDialogFont: bool) -> None: ...
    def storeTo(self, arg: Union[OutputStream, Writer]) -> None: ...
    def useCondensedDialogFont(self) -> bool: ...

    class Jar(Object):
        def __init__(self, name: AnyStr, crc32: long, length: long) -> None: ...
        def getCrc32(self) -> long: ...
        def getLength(self) -> long: ...
        def getName(self) -> AnyStr: ...

    class Module(Object):
        def __init__(self, name: AnyStr, build: int) -> None: ...
        def addJar(self, file: LaunchManifest.Jar) -> None: ...
        def getBuild(self) -> int: ...
        def getJarFiles(self) -> List[LaunchManifest.Jar]: ...
        def getName(self) -> AnyStr: ...

class LaunchableApp(JPanel):
    def __init__(self, *args: Any) -> None: ...
    def canShutdown(self) -> bool: ...
    def getFrameIcon(self) -> Image: ...
    def getFrameTitle(self) -> AnyStr: ...
    def getGlassPane(self) -> JComponent: ...
    def getInitialFrameSize(self) -> Dimension: ...
    def getScreenIndex(self) -> int: ...
    def isStartCentered(self) -> bool: ...
    def isStartMaximized(self) -> bool: ...
    def setFrameIcon(self, frameIcon: Image) -> None: ...
    def setFrameTitle(self, frameTitle: AnyStr) -> None: ...
    def setGlassPane(self, frameIcon: JComponent) -> None: ...
    def shutdown(self) -> None: ...



from typing import Any

from dev.thecesrom.helper.types import AnyStr
from java.lang import Object, StringBuffer

class ToStringStyle(Object):
    DEFAULT_STYLE: ToStringStyle
    JSON_STYLE: ToStringStyle
    MULTI_LINE_STYLE: ToStringStyle
    NO_CLASS_NAME_STYLE: ToStringStyle
    NO_FIELD_NAMES_STYLE: ToStringStyle
    SHORT_PREFIX_STYLE: ToStringStyle
    SIMPLE_STYLE: ToStringStyle
    def append(self, buffer: StringBuffer, fieldName: AnyStr, *args: Any) -> None: ...
    def appendEnd(self, buffer: StringBuffer, obj: Any) -> None: ...
    def appendStart(self, buffer: StringBuffer, obj: Any) -> None: ...
    def appendSuper(self, buffer: StringBuffer, superToString: AnyStr) -> None: ...
    def appendToString(self, buffer: StringBuffer, toString: AnyStr) -> None: ...



from typing import Any

from dev.thecesrom.helper.types import AnyStr
from java.lang import Class, Exception, Object

class ClassNameResolver(Object):
    def __init__(self) -> None: ...
    def addAlias(self, clazz: Class, alias: AnyStr) -> None: ...
    def addDefaults(self) -> None: ...
    def addSearchPath(self, path: AnyStr) -> None: ...
    def classForName(self, name: AnyStr) -> Class: ...
    def createBasic(self) -> ClassNameResolver: ...
    def getName(self, clazz: Class) -> AnyStr: ...

class SerializationException(Exception):
    def __init__(self, *args: Any) -> None: ...



from typing import Any, List, Optional

from com.inductiveautomation.ignition.common.gui.progress import (
    TaskProgressListener,
    TaskProgressState,
)
from dev.thecesrom.helper.types import AnyStr
from java.lang import Object
from java.util.concurrent import CompletableFuture
from java.util.function import Consumer

class AsyncClientTask:
    def canCancel(self) -> bool: ...
    def getTaskTitle(self) -> AnyStr: ...
    def run(self, progressListener: TaskProgressListener) -> None: ...

class TaskHandle:
    def cancel(self) -> None: ...
    def getUid(self) -> AnyStr: ...
    def waitForResult(self, timeout: int) -> Object: ...

class ClientProgressManager(Object):
    def addListener(self, listener: ClientProgressManager.ModelListener) -> None: ...
    def cancelAllTasks(self) -> None: ...
    def cancelTask(self, uid: AnyStr) -> None: ...
    @staticmethod
    def getInstance() -> ClientProgressManager: ...
    def getStates(self) -> List[TaskProgressState]: ...
    def registerGatewayTask(self, taskId: AnyStr) -> TaskHandle: ...
    def removeListener(self, listener: ClientProgressManager.ModelListener) -> None: ...
    def run(self, cf: CompletableFuture, handler: Consumer, owner: Object) -> None: ...
    def runTask(
        self, task: AsyncClientTask, dominant: Optional[bool] = ...
    ) -> TaskHandle: ...
    def setClientContext(self, context: Any) -> None: ...
    def setUIPaused(self, value: bool) -> None: ...
    def shutdown(self) -> None: ...
    def startup(self) -> None: ...

    class ModelListener:
        def progressModelChanged(self) -> None: ...



from typing import Any

from java.lang import Object

class TypeToken(Object):
    @staticmethod
    def get(type: Any) -> TypeToken: ...
    @staticmethod
    def getArray(componentType: Any) -> TypeToken: ...
    @staticmethod
    def getParameterized(*args: Any) -> TypeToken: ...



from typing import Any, Optional

from com.inductiveautomation.ignition.common import Path
from com.inductiveautomation.ignition.common.browsing import BrowseFilter
from com.inductiveautomation.ignition.common.config import Property
from com.inductiveautomation.ignition.common.gson import (
    JsonDeserializationContext,
    JsonElement,
    JsonSerializationContext,
)
from com.inductiveautomation.ignition.common.user import AuthenticatedUser
from dev.thecesrom.helper.types import AnyStr
from java.lang import Comparable, Object
from java.lang.reflect import Type

class TagManager:
    def browseAsync(
        self,
        tagPath: TagPath,
        browseFilter: BrowseFilter,
        securityContext: Optional[SecurityContext] = ...,
    ) -> Any: ...

class SecurityContext(Object):
    @staticmethod
    def emptyContext() -> SecurityContext: ...
    @staticmethod
    def fromAuthenticatedUser(user: AuthenticatedUser) -> SecurityContext: ...

    class GsonAdapter(Object):
        def __init__(self) -> None: ...
        def deserialize(
            self,
            jsonElement: JsonElement,
            type_: Type,
            jsonDeserializationContext: JsonDeserializationContext,
        ) -> SecurityContext: ...
        def serialize(
            self,
            securityContext: SecurityContext,
            type_: Type,
            jsonSerializationContext: JsonSerializationContext,
        ) -> JsonElement: ...

class TagPath(Path, Comparable):
    def compareTo(self, o: TagPath) -> int: ...
    def getChildPath(self, nextId: AnyStr) -> TagPath: ...
    def getItemName(self) -> AnyStr: ...
    def getLastPathComponent(self) -> AnyStr: ...
    def getParentPath(self) -> TagPath: ...
    def getPathComponent(self, i: int) -> AnyStr: ...
    def getPathLength(self) -> int: ...
    def getProperty(self) -> Property: ...
    def getSource(self) -> AnyStr: ...
    def isAncestorOf(self, path: Path) -> bool: ...
    def toStringFull(self) -> AnyStr: ...
    def toStringPartial(self) -> AnyStr: ...



from typing import Any, Iterable, Optional, Union

from com.inductiveautomation.ignition.common.gson.reflect import TypeToken
from com.inductiveautomation.ignition.common.gson.stream import JsonReader, JsonWriter
from dev.thecesrom.helper.types import AnyNum, AnyStr
from java.io import Reader, Writer
from java.lang import Class, Enum, Object
from java.lang.reflect import Type

class ExclusionStrategy:
    def shouldSkipClass(self, clazz: Class) -> bool: ...
    def shouldSkipField(self, attributes: FieldAttributes) -> bool: ...

class FieldNamingStrategy:
    def translateName(self, arg: Any) -> AnyStr: ...

class JsonDeserializationContext:
    def deserialize(self, var1: JsonElement, var2: Type) -> Any: ...

class JsonSerializationContext:
    def serialize(self, var1: Object, var2: Optional[Type] = ...) -> JsonElement: ...

class TypeAdapterFactory:
    def create(self, gson: Gson, token: TypeToken) -> TypeAdapter: ...

class FieldAttributes(Object):
    def __init__(self, *args: Any) -> None: ...
    def getAnnotation(self, annotation: Class) -> Any: ...
    def getAnnotations(self) -> Iterable[Any]: ...
    def getDeclaredClass(self) -> Class: ...
    def getDeclaredType(self) -> Any: ...
    def getDeclaringClass(self) -> Class: ...
    def getName(self) -> AnyStr: ...
    def hasModifier(self, modifier: int) -> bool: ...
    def isSynthetic(self) -> bool: ...

class FieldNamingPolicy(Enum, FieldNamingStrategy):
    IDENTITY: AnyStr
    UPPER_CAMEL_CASE: AnyStr
    UPPER_CAMEL_CASE_WITH_SPACES: AnyStr
    LOWER_CASE_WITH_UNDERSCORES: AnyStr
    LOWER_CASE_WITH_DASHES: AnyStr
    LOWER_CASE_WITH_DOTS: AnyStr
    def translateName(self, arg: Any) -> AnyStr: ...

class Gson(Object):
    def excluder(self) -> Any: ...
    def fieldNamingStrategy(self) -> FieldNamingStrategy: ...
    def fromJson(self, *args: Any) -> Any: ...
    def getAdapter(self, type: Optional[TypeToken] = ...) -> TypeAdapter: ...
    def getDelegateAdapter(
        self, skipPast: TypeAdapterFactory, type: TypeToken
    ) -> TypeAdapter: ...
    def htmlSafe(self) -> bool: ...
    def newBuilder(self) -> GsonBuilder: ...
    def newJsonReader(self, reader: Reader) -> JsonReader: ...
    def newJsonWriter(self, writer: Writer) -> JsonWriter: ...
    def serializeNulls(self) -> bool: ...
    def toJson(self, *args: Any) -> Optional[AnyStr]: ...
    def toJsonTree(self, src: Object, typeOfSrc: Any = ...) -> JsonElement: ...

class GsonBuilder:
    def __init__(self, *args: Any) -> None: ...
    def addDeserializationExclusionStrategy(
        self, strategy: ExclusionStrategy
    ) -> GsonBuilder: ...
    def addSerializationExclusionStrategy(
        self, strategy: ExclusionStrategy
    ) -> GsonBuilder: ...
    def create(self) -> Gson: ...
    def disableHtmlEscaping(self) -> GsonBuilder: ...
    def disableInnerClassSerialization(self) -> GsonBuilder: ...
    def enableComplexMapKeySerialization(self) -> GsonBuilder: ...
    def excludeFieldsWithoutExposeAnnotation(self) -> GsonBuilder: ...
    def excludeFieldsWithModifiers(self, *args: int) -> GsonBuilder: ...
    def generateNonExecutableJson(self) -> GsonBuilder: ...
    def setLenient(self) -> GsonBuilder: ...
    def registerTypeAdapter(self, type: Any, typeAdapter: Object) -> GsonBuilder: ...
    def registerTypeAdapterFactory(
        self, factory: TypeAdapterFactory
    ) -> GsonBuilder: ...
    def registerTypeHierarchyAdapter(
        self, baseType: Class, typeAdapter: Object
    ) -> GsonBuilder: ...
    def serializeNulls(self) -> GsonBuilder: ...
    def serializeSpecialFloatingPointValues(self) -> GsonBuilder: ...
    def setDateFormat(self, *args: Any) -> GsonBuilder: ...
    def setExclusionStrategies(self, *args: ExclusionStrategy) -> GsonBuilder: ...
    def setFieldNamingPolicy(
        self, namingConvention: FieldNamingPolicy
    ) -> GsonBuilder: ...
    def setFieldNamingStrategy(
        self, fieldNamingStrategy: FieldNamingStrategy
    ) -> GsonBuilder: ...
    def setLongSerializationPolicy(
        self, policy: LongSerializationPolicy
    ) -> GsonBuilder: ...
    def setPrettyPrinting(self) -> GsonBuilder: ...
    def setVersion(self, ignoreVersionsAfter: float) -> GsonBuilder: ...

class JsonElement:
    def deepCopy(self) -> JsonElement: ...
    def getAsBigDecimal(self) -> float: ...
    def getAsBigInteger(self) -> int: ...
    def getAsBoolean(self) -> bool: ...
    def getAsByte(self) -> Any: ...
    def getAsCharacter(self) -> str: ...
    def getAsDouble(self) -> float: ...
    def getAsFloat(self) -> float: ...
    def getAsInt(self) -> int: ...
    def getAsJsonArray(self) -> JsonArray: ...
    def getAsJsonObject(self) -> JsonObject: ...
    def getAsJsonPrimitive(self) -> JsonPrimitive: ...
    def getAsJsonNull(self) -> JsonNull: ...
    def getAsLong(self) -> long: ...
    def getAsNumber(self) -> AnyNum: ...
    def getAsShort(self) -> int: ...
    def isJsonArray(self) -> bool: ...
    def isJsonObject(self) -> bool: ...
    def isJsonPrimitive(self) -> bool: ...
    def isJsonNull(self) -> bool: ...

class JsonArray(JsonElement):
    def __init__(self, capacity: Optional[int] = ...) -> None: ...
    def add(self, arg: Any) -> None: ...
    def addAll(self, array: JsonArray) -> None: ...
    def contains(self, element: JsonElement) -> bool: ...
    def get(self, i: int) -> JsonElement: ...
    def getAsBigDecimal(self) -> float: ...
    def getAsBigInteger(self) -> int: ...
    def getAsBoolean(self) -> bool: ...
    def getAsByte(self) -> Any: ...
    def getAsCharacter(self) -> str: ...
    def getAsDouble(self) -> float: ...
    def getAsFloat(self) -> float: ...
    def getAsInt(self) -> int: ...
    def getAsLong(self) -> long: ...
    def getAsNumber(self) -> AnyNum: ...
    def getAsShort(self) -> int: ...
    def iterator(self) -> Iterable[JsonElement]: ...
    def remove(self, index: int) -> JsonElement: ...
    def size(self) -> int: ...

class JsonNull(JsonElement):
    def equals(self, other: Object) -> bool: ...
    def getAsBigDecimal(self) -> float: ...
    def getAsBigInteger(self) -> int: ...
    def getAsBoolean(self) -> bool: ...
    def getAsByte(self) -> Any: ...
    def getAsCharacter(self) -> str: ...
    def getAsDouble(self) -> float: ...
    def getAsFloat(self) -> float: ...
    def getAsInt(self) -> int: ...
    def getAsLong(self) -> long: ...
    def getAsNumber(self) -> AnyNum: ...
    def getAsShort(self) -> int: ...
    def hashCode(self) -> int: ...

class JsonObject(JsonElement):
    def add(self, property: AnyStr, value: JsonElement) -> None: ...
    def addProperty(self, property: AnyStr, value: Any) -> None: ...
    def createJsonElement(self, value: Object) -> JsonElement: ...
    def get(self, memberName: AnyStr) -> JsonElement: ...
    def getAsBigDecimal(self) -> float: ...
    def getAsBigInteger(self) -> int: ...
    def getAsBoolean(self) -> bool: ...
    def getAsByte(self) -> Any: ...
    def getAsCharacter(self) -> str: ...
    def getAsDouble(self) -> float: ...
    def getAsFloat(self) -> float: ...
    def getAsInt(self) -> int: ...
    def getAsLong(self) -> long: ...
    def getAsNumber(self) -> AnyNum: ...
    def getAsShort(self) -> int: ...
    def has(self, memberName: AnyStr) -> bool: ...
    def remove(self, property: AnyStr) -> JsonElement: ...
    def size(self) -> int: ...

class JsonPrimitive(JsonElement):
    def __init__(self, arg: Any) -> None: ...
    def equals(self, other: Object) -> bool: ...
    def getAsBigDecimal(self) -> float: ...
    def getAsBigInteger(self) -> int: ...
    def getAsBoolean(self) -> bool: ...
    def getAsByte(self) -> Any: ...
    def getAsCharacter(self) -> str: ...
    def getAsDouble(self) -> float: ...
    def getAsFloat(self) -> float: ...
    def getAsInt(self) -> int: ...
    def getAsLong(self) -> long: ...
    def getAsNumber(self) -> AnyNum: ...
    def getAsShort(self) -> int: ...
    def hashCode(self) -> int: ...
    def isBoolean(self) -> bool: ...
    @staticmethod
    def isPrimitiveOrString(target: Object) -> bool: ...
    @staticmethod
    def isIntegral(primitive: JsonPrimitive) -> bool: ...
    def isString(self) -> bool: ...

class LongSerializationPolicy:
    DEFAULT: JsonElement
    STRING: JsonElement
    def serialize(self, arg: long) -> JsonElement: ...

class TypeAdapter:
    def fromJson(self, arg: Union[Reader, AnyStr]) -> Any: ...
    def fromJsonTree(self, jsonTree: JsonElement) -> Any: ...
    def nullSafe(self) -> TypeAdapter: ...
    def read(self, reader: JsonReader) -> Any: ...
    def toJson(self, out: Writer, value: Any) -> Optional[AnyStr]: ...
    def toJsonTree(self, value: Any) -> JsonElement: ...
    def write(self, var1: JsonWriter, var2: Any) -> None: ...



from typing import Any, Iterable, Set

from java.lang import AutoCloseable, Enum, Runnable
from java.util import Iterator, Spliterator
from java.util.function import BiConsumer, BinaryOperator, Consumer, Function, Supplier

class BaseStream(AutoCloseable):
    def close(self) -> None: ...
    def isParallel(self) -> bool: ...
    def iterator(self) -> Iterator: ...
    def onClose(self, closeHandler: Runnable) -> Any: ...
    def parallel(self) -> Any: ...
    def sequential(self) -> Any: ...
    def spliterator(self) -> Spliterator: ...
    def unordered(self) -> Any: ...

class Collector:
    def accumulator(self) -> BiConsumer: ...
    def characteristic(self) -> Set[Collector.Characteristics]: ...
    def combiner(self) -> BinaryOperator: ...
    def finisher(self) -> Function: ...
    @staticmethod
    def of(*args: Any) -> Collector: ...
    def supplier(self) -> Supplier: ...

    class Characteristics(Enum):
        @staticmethod
        def values() -> Iterable[Collector.Characteristics]: ...

class Stream(BaseStream):
    @staticmethod
    def builder() -> Stream.Builder: ...
    def close(self) -> None: ...
    def isParallel(self) -> bool: ...
    def iterator(self) -> Iterator: ...
    def onClose(self, closeHandler: Runnable) -> Any: ...
    def parallel(self) -> Any: ...
    def sequential(self) -> Any: ...
    def spliterator(self) -> Spliterator: ...
    def unordered(self) -> Any: ...

    class Builder(Consumer):
        def accept(self, t: Any) -> None: ...
        def add(self, t: Any) -> Stream.Builder: ...
        def build(self) -> Stream: ...



from java.awt import AWTEvent, Component, Container

class AncestorEvent(AWTEvent):
    ANCESTOR_ADDED: int
    ANCESTOR_MOVED: int
    ANCESTOR_REMOVED: int
    def __init__(
        self, source: Component, id: int, ancestor: Container, ancestorParent: Container
    ) -> None: ...
    def getAncestor(self) -> Container: ...
    def getAncestorParent(self) -> Container: ...
    def getComponent(self) -> Component: ...

class AncestorListener:
    def ancestorAdded(self, event: AncestorEvent) -> None: ...
    def ancestorMoved(self, event: AncestorEvent) -> None: ...
    def ancestorRemoved(self, event: AncestorEvent) -> None: ...



from typing import Any, Dict, Iterable, List, Mapping, Optional, Set, Union

from dev.thecesrom.helper.types import AnyStr
from java.lang import Class, Object
from java.time import Instant, ZoneId
from java.util.function import (
    BiFunction,
    Consumer,
    Function,
    Predicate,
    Supplier,
    ToDoubleFunction,
    ToIntFunction,
    ToLongFunction,
)

class Collection:
    def add(self, e: Any) -> bool: ...
    def addAll(self, c: Collection) -> bool: ...
    def clear(self) -> None: ...
    def contains(self, o: Object) -> bool: ...
    def containsAll(self, c: Collection) -> bool: ...
    def equals(self, o: Object) -> bool: ...
    def forEach(self, action: Consumer) -> None: ...
    def hashCode(self) -> int: ...
    def isEmpty(self) -> bool: ...
    def iterator(self) -> Iterator: ...
    def parallelStream(self) -> Stream: ...
    def remove(self, o: Object) -> bool: ...
    def removeAll(self, c: Collection) -> bool: ...
    def removeIf(self, filter: Predicate) -> bool: ...
    def retainAll(self, v: Collection) -> bool: ...
    def size(self) -> int: ...
    def spliterator(self) -> Spliterator: ...
    def stream(self) -> Stream: ...
    def toArray(self, arg: Optional[Any] = ...) -> List[Object]: ...

class Comparator:
    def compare(self, o1: Any, o2: Any) -> int: ...
    @staticmethod
    def comparing(keyExtractor: Function, keyComparator: Comparator) -> Comparator: ...
    @staticmethod
    def comparingDouble(keyExtractor: ToDoubleFunction) -> Comparator: ...
    @staticmethod
    def comparingInt(keyExtractor: ToIntFunction) -> Comparator: ...
    @staticmethod
    def comparingLong(keyExtractor: ToLongFunction) -> Comparator: ...
    def equals(self, obj: Object) -> bool: ...
    @staticmethod
    def naturalOrder() -> Comparator: ...
    @staticmethod
    def nullsFirst(comparator: Comparator) -> Comparator: ...
    @staticmethod
    def nullsLast(comparator: Comparator) -> Comparator: ...
    def reversed(self) -> Comparator: ...
    @staticmethod
    def reverseOrder() -> Comparator: ...
    def thenComparing(self, *args: Any) -> Comparator: ...
    def thenComparingDouble(self, keyExtractor: ToDoubleFunction) -> Comparator: ...
    def thenComparingInt(self, keyExtractor: ToIntFunction) -> Comparator: ...
    def thenComparingLong(self, keyExtractor: ToLongFunction) -> Comparator: ...

class Enumeration:
    def asIterator(self) -> Iterator: ...
    def hasMoreElements(self) -> bool: ...
    def nextElement(self) -> Any: ...

class Iterator:
    def forEachRemaining(self, action: Consumer) -> None: ...
    def hasNext(self) -> bool: ...
    def next(self) -> Any: ...
    def remove(self) -> bool: ...

class ListIterator(Iterator):
    def add(self, e: Any) -> None: ...
    def hasNext(self) -> bool: ...
    def hasPrevious(self) -> bool: ...
    def next(self) -> Any: ...
    def nextIndex(self) -> int: ...
    def previous(self) -> Any: ...
    def previousIndex(self) -> int: ...
    def set(self, e: Any) -> None: ...

class Map:
    def clear(self) -> None: ...
    def compute(self, key: Any, remappingFuntion: BiFunction) -> Any: ...
    def computeIfAbsent(self, key: Any, mappingFuntion: BiFunction) -> Any: ...
    def computeIfPresent(self, key: Any, remappingFuntion: BiFunction) -> Any: ...
    def containsKey(self, key: Object) -> bool: ...
    def containsValue(self, value: Object) -> bool: ...
    @staticmethod
    def copyOf(map: Map) -> Map: ...
    @staticmethod
    def entry(k: Any, v: Any) -> Map.Entry: ...
    def entrySet(self) -> Set[Map.Entry]: ...
    def forEach(self, action: BiFunction) -> None: ...
    def get(self, key: Object) -> Any: ...
    def getOrDefault(self, key: Object, defaultValue: Any) -> Any: ...
    def isEmpty(self) -> bool: ...
    def keySet(self) -> Set[Any]: ...
    def merge(self, key: Any, value: Any, remappingFunction: BiFunction) -> Any: ...
    @staticmethod
    def of(*args: Any) -> Map: ...
    @staticmethod
    def ofEntries(*entries: Map.Entry) -> Map: ...
    def put(self, key: Any, value: Any) -> Any: ...
    def putAll(self, m: Mapping[Any, Any]) -> None: ...
    def putIfAbsent(self, key: Any, value: Any) -> Any: ...
    def remove(self, key: Object) -> Any: ...
    def replace(self, *args: Any) -> Union[Any, bool]: ...
    def replaceAll(self, function: BiFunction) -> None: ...
    def size(self) -> int: ...
    def values(self) -> Collection: ...

    class Entry:
        @staticmethod
        def comparingByKey(cmp: Optional[Comparator] = ...) -> Any: ...
        @staticmethod
        def comparingByValue(cmp: Optional[Comparator] = ...) -> Any: ...
        def getKey(self) -> Any: ...
        def getValue(self) -> Any: ...
        def hashCode(self) -> int: ...
        def setValue(self, value: Any) -> Any: ...

class Spliterator:
    CONCURRENT: int
    DISTINCT: int
    IMMUTABLE: int
    NONNULL: int
    ORDERED: int
    SIZED: int
    SORTED: int
    SUBSIZED: int
    def characteristics(self) -> int: ...
    def estimateSize(self) -> long: ...
    def forEachRemaining(self, action: Consumer) -> None: ...
    def getComparator(self) -> Comparator: ...
    def getExactSizeIfKnown(self) -> long: ...
    def hasCharacteristics(self, characteristics: int) -> bool: ...
    def tryAdvance(self, action: Consumer) -> bool: ...
    def trySplit(self) -> Spliterator: ...

class Stream:
    @staticmethod
    def builder() -> Builder: ...
    @staticmethod
    def concat(a: Stream, b: Stream) -> Stream: ...
    @staticmethod
    def empty() -> Stream: ...
    @staticmethod
    def generate(s: Supplier) -> Stream: ...
    @staticmethod
    def iterate(*args: Any) -> Stream: ...
    @staticmethod
    def of(*args: Any) -> Stream: ...
    @staticmethod
    def ofNullable(t: Any) -> Stream: ...

    class Builder(Consumer):
        def accept(self, t: Any) -> None: ...
        def add(self, t: Any) -> Stream.Builder: ...
        def build(self) -> Stream: ...

class Arrays(Object):
    @staticmethod
    def asList(a: Any) -> List[Any]: ...
    @staticmethod
    def binarySearch(*args: Any, **kwargs: Any) -> int: ...
    @staticmethod
    def compare(*args: Any, **kwargs: Any) -> int: ...
    @staticmethod
    def compareUnsigned(*args: Any, **kwargs: Any) -> int: ...
    @staticmethod
    def copyOf(
        original: List[Any], newLength: int, newType: Optional[Class] = ...
    ) -> List[Any]: ...
    @staticmethod
    def copyOfRange(
        original: List[Any], from_: int, to: int, newType: Optional[Class] = ...
    ) -> List[Any]: ...
    @staticmethod
    def deepEquals(a1: List[Object], a2: List[Object]) -> bool: ...
    @staticmethod
    def equals(*args: Any, **kwargs: Any) -> bool: ...
    @staticmethod
    def fill(a: List[Any], *args: Any) -> None: ...
    @staticmethod
    def mismatch(*args: Any, **kwargs: Any) -> int: ...
    @staticmethod
    def parallelPrefix(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def parallelSetAll(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def parallelSort(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def setAll(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def sort(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def spliterator(
        array: Iterable[Any],
        startInclusive: Optional[int] = ...,
        endExclusive: Optional[int] = ...,
    ) -> Spliterator: ...
    @staticmethod
    def stream(
        array: Iterable[Any],
        startInclusive: Optional[int] = ...,
        endExclusive: Optional[int] = ...,
    ) -> Stream: ...

class AbstractCollection(Object, Collection):
    def add(self, e: Any) -> bool: ...
    def addAll(self, c: Collection) -> bool: ...
    def clear(self) -> None: ...
    def contains(self, o: Object) -> bool: ...
    def containsAll(self, c: Collection) -> bool: ...
    def isEmpty(self) -> bool: ...
    def iterator(self) -> Iterator: ...
    def remove(self, o: Object) -> bool: ...
    def removeAll(self, c: Collection) -> bool: ...
    def retainAll(self, v: Collection) -> bool: ...
    def size(self) -> int: ...

class AbstractMap(Object, Map):
    def clear(self) -> None: ...
    def containsKey(self, key: Object) -> bool: ...
    def containsValue(self, value: Object) -> bool: ...
    def entrySet(self) -> Set[Map.Entry]: ...
    def get(self, key: Object) -> Any: ...
    def isEmpty(self) -> bool: ...
    def keySet(self) -> Set[Any]: ...
    def put(self, key: Any, value: Any) -> Any: ...
    def putAll(self, m: Mapping[Any, Any]) -> None: ...
    def remove(self, key: Object) -> Any: ...
    def size(self) -> int: ...
    def values(self) -> Collection: ...

class Calendar(Object):
    ALL_STYLES: int
    AM: int
    AM_PM: int
    APRIL: int
    AUGUST: int
    DATE: int
    DAY_OF_MONTH: int
    DAY_OF_WEEK: int
    DAY_OF_WEEK_IN_MONTH: int
    DAY_OF_YEAR: int
    DECEMBER: int
    DST_OFFSET: int
    ERA: int
    FEBRUARY: int
    FIELD_COUNT: int
    FRIDAY: int
    HOUR: int
    HOUR_OF_DAY: int
    JANUARY: int
    JULY: int
    JUNE: int
    LONG: int
    LONG_FORMAT: int
    LONG_STANDALONE: int
    MARCH: int
    MAY: int
    MILLISECOND: int
    MINUTE: int
    MONDAY: int
    MONTH: int
    NARROW_FORMAT: int
    NARROW_STANDALONE: int
    NOVEMBER: int
    OCTOBER: int
    PM: int
    SATURDAY: int
    SECOND: int
    SEPTEMBER: int
    SHORT: int
    SHORT_FORMAT: int
    SHORT_STANDALONE: int
    SUNDAY: int
    THURSDAY: int
    TUESDAY: int
    UNDECIMBER: int
    WEDNESDAY: int
    WEEK_OF_MONTH: int
    WEEK_OF_YEAR: int
    YEAR: int
    ZONE_OFFSET: int
    def add(self, field: int, amount: int) -> None: ...
    def after(self, when: Object) -> bool: ...
    def before(self, when: Object) -> bool: ...
    def clear(self, field: Optional[int] = ...) -> None: ...
    def clone(self) -> Object: ...
    def compareTo(self, anotherCalendar: Calendar) -> int: ...
    def get(self, field: int) -> int: ...
    def getActualMaximum(self, field: int) -> int: ...
    def getActualMinimum(self, field: int) -> int: ...
    @staticmethod
    def getAvailableCalendarTypes() -> Set[AnyStr]: ...
    @staticmethod
    def getAvailableLocales() -> List[Locale]: ...
    def getCalendarType(self) -> AnyStr: ...
    def getDisplayName(self, field: int, style: int, locale: Locale) -> AnyStr: ...
    def getDisplayNames(
        self, field: int, style: int, locale: Locale
    ) -> Dict[AnyStr, int]: ...
    def getFirstDayOfWeek(self) -> int: ...
    def getGreatestMinimum(self, field: int) -> int: ...
    def getInstance(self, *args: Any) -> Calendar: ...
    def getTimeZone(self) -> TimeZone: ...
    def getWeeksInWeekYear(self) -> int: ...
    def getWeekYear(self) -> int: ...
    def isLenient(self) -> bool: ...
    def isSet(self, field: int) -> bool: ...
    def isWeekDateSUpported(self) -> bool: ...
    def roll(self, field: int, amount: int) -> None: ...
    def set(self, *args: int) -> None: ...
    def setFirstDayOfWeek(self, value: int) -> None: ...
    def setLenient(self, lenient: bool) -> None: ...
    def setMinimalDaysInFirstWeek(self, value: int) -> None: ...
    def setTime(self, date: Date) -> None: ...
    def setTimeInMillis(self, millis: long) -> None: ...
    def setTimeZone(self, value: TimeZone) -> None: ...
    def setWeekDate(self, weekYear: int, weekOfYear: int, dayOfWeek: int) -> None: ...
    def toInstant(self) -> Instant: ...

class Currency(Object):
    @staticmethod
    def getAvailableCurrencies() -> Set[Currency]: ...
    def getCurrencyCode(self) -> AnyStr: ...
    def getDisplayName(self, locale: Optional[Locale] = ...) -> AnyStr: ...
    @staticmethod
    def getInstance(arg: Union[Locale, AnyStr]) -> Currency: ...
    def getNumericCode(self) -> int: ...
    def getNumericCodeAsString(self) -> AnyStr: ...
    def getSymbol(self, locale: Optional[Locale] = ...) -> AnyStr: ...

class Date(Object):
    def __init__(self, date: Optional[long] = ...) -> None: ...
    def after(self, when: Date) -> bool: ...
    def before(self, when: Date) -> bool: ...
    def compareTo(self, anotherDate: Date) -> int: ...
    def getTime(self) -> long: ...
    def setTime(self, time: long) -> None: ...

class Dictionary(Object):
    def __init__(self) -> None: ...
    def elements(self) -> Enumeration: ...
    def get(self, key: Object) -> Any: ...
    def isEmpty(self) -> bool: ...
    def keys(self) -> Enumeration: ...
    def put(self, key: Any, value: Any) -> Any: ...
    def remove(self, key: Object) -> Any: ...
    def size(self) -> int: ...

class EventObject(Object):
    def __init__(self, source: Object) -> None: ...
    def getSource(self) -> Object: ...

class HashMap(AbstractMap, Map):
    def __init__(self, *args: Any) -> None: ...
    def entrySet(self) -> Set[Map.Entry]: ...

class Hashtable(Dictionary, Map):
    def __init__(self, *args: Any) -> None: ...
    def clear(self) -> None: ...
    def clone(self) -> Object: ...
    def contains(self, value: Object) -> bool: ...
    def containsKey(self, key: Object) -> bool: ...
    def containsValue(self, value: Object) -> bool: ...
    def elements(self) -> Enumeration: ...
    def entrySet(self) -> Set[Map.Entry]: ...
    def get(self, key: Object) -> Any: ...
    def isEmpty(self) -> bool: ...
    def keySet(self) -> Set[Any]: ...
    def keys(self) -> Enumeration: ...
    def put(self, key: Any, value: Any) -> Any: ...
    def putAll(self, m: Mapping[Any, Any]) -> None: ...
    def remove(self, key: Object) -> Any: ...
    def size(self) -> int: ...
    def values(self) -> Collection: ...

class Locale(Object):
    country: Optional[str]
    language: str
    variant: Optional[str]
    def __init__(
        self, language: str, country: Optional[str] = ..., variant: Optional[str] = ...
    ) -> None: ...
    def CANADA(self) -> Locale: ...
    def CANADA_FRENCH(self) -> Locale: ...
    def CHINA(self) -> Locale: ...
    def CHINESE(self) -> Locale: ...
    def ENGLISH(self) -> Locale: ...
    def FRANCE(self) -> Locale: ...
    def FRENCH(self) -> Locale: ...
    def GERMAN(self) -> Locale: ...
    def GERMANY(self) -> Locale: ...
    def ITALIAN(self) -> Locale: ...
    def ITALY(self) -> Locale: ...
    def JAPAN(self) -> Locale: ...
    def JAPANESE(self) -> Locale: ...
    def KOREA(self) -> Locale: ...
    def KOREAN(self) -> Locale: ...
    def PRC(self) -> Locale: ...
    def SIMPLIFIED_CHINESE(self) -> Locale: ...
    def TAIWAN(self) -> Locale: ...
    def TRADITIONAL_CHINESE(self) -> Locale: ...
    def UK(self) -> Locale: ...
    def US(self) -> Locale: ...

class Properties(Hashtable):
    def __init__(self, *args: Any) -> None: ...

class TimeZone(Object):
    LONG: int
    SHORT: int
    def __init__(self) -> None: ...
    def clone(self) -> Object: ...
    @staticmethod
    def getAvailableIDs(rawOffset: Optional[int] = ...) -> List[AnyStr]: ...
    @staticmethod
    def getDefault() -> TimeZone: ...
    def getDisplayName(self, *args: Any) -> AnyStr: ...
    def getDSTSavings(self) -> int: ...
    def getID(self) -> AnyStr: ...
    def getOffset(self, *args: Any) -> int: ...
    def getRawOffset(self) -> int: ...
    @staticmethod
    def getTimeZone(arg: Union[AnyStr, ZoneId]) -> TimeZone: ...
    def hasSameRules(self, other: TimeZone) -> bool: ...
    def isDaylightTime(self, date: Date) -> bool: ...
    def observesDaylightTime(self) -> bool: ...
    @staticmethod
    def setDefault(zone: TimeZone) -> None: ...
    def setID(self, ID: AnyStr) -> None: ...
    def setRawOffset(self, offsetMillis: int) -> None: ...
    def toZoneId(self) -> ZoneId: ...
    def useDaylightTime(self) -> bool: ...

class UUID(Object):
    def __init__(self, mostSigBits: long, leastSigBits: long) -> None: ...
    def clockSequence(self) -> int: ...
    def compareTo(self, val: UUID) -> int: ...
    @staticmethod
    def fromString(name: AnyStr) -> UUID: ...
    def getLeastSignificantBits(self) -> long: ...
    def getMostSignificantBits(self) -> long: ...
    @staticmethod
    def nameUUIDFromBytes(name: bytearray) -> UUID: ...
    def node(self) -> long: ...
    @staticmethod
    def randomUUID() -> UUID: ...
    def timestamp(self) -> long: ...
    def variant(self) -> int: ...
    def version(self) -> int: ...



from typing import Iterable

from dev.thecesrom.helper.types import AnyStr
from java.lang import Enum

class TagObjectType(Enum):
    @staticmethod
    def fromString(value: AnyStr) -> TagObjectType: ...
    def isComplexTag(self) -> bool: ...
    @staticmethod
    def values() -> Iterable[TagObjectType]: ...



from java.awt import Component, Graphics
from java.lang import Object

class ComponentUI(Object):
    def __init__(self) -> None: ...
    def contains(self, c: Component, x: int, y: int) -> bool: ...
    def paint(self, g: Graphics, c: Component) -> None: ...
    def update(self, g: Graphics, c: Component) -> None: ...

class DesktopPaneUI(ComponentUI):
    def __init__(self) -> None: ...



from typing import Any, List

from com.google.common.eventbus import EventBus
from com.inductiveautomation.ignition.client.launch import LaunchContext
from com.inductiveautomation.ignition.client.util.gui.progress import (
    ClientProgressManager,
)
from com.inductiveautomation.ignition.common.db.namedquery import NamedQueryManager
from com.inductiveautomation.ignition.common.execution import ExecutionManager
from com.inductiveautomation.ignition.common.expressions import FunctionFactory
from com.inductiveautomation.ignition.common.i18n.translation import TranslationMap
from com.inductiveautomation.ignition.common.licensing import LicenseState
from com.inductiveautomation.ignition.common.logging import LogFilterSettings
from com.inductiveautomation.ignition.common.model import CommonContext, EdgeEdition
from com.inductiveautomation.ignition.common.modules import ModuleInfo
from com.inductiveautomation.ignition.common.project import Project
from com.inductiveautomation.ignition.common.script import ScriptManager
from com.inductiveautomation.ignition.common.tags.model import TagManager
from com.inductiveautomation.ignition.common.xmlserialization.deserialization import (
    XMLDeserializer,
)
from dev.thecesrom.helper.types import AnyStr
from java.beans import PropertyChangeListener
from java.lang import Object
from java.util import Locale
from javax.swing import RootPaneContainer
from org.apache.log4j import Logger

class ClientContext(CommonContext):
    def addPropertyChangeListener(self, *args: Any) -> None: ...
    def createDeserializer(self) -> XMLDeserializer: ...
    def desearilize(self, data: bytearray, log: Logger) -> Object: ...
    def getAuthProfileName(self) -> AnyStr: ...
    def getDefaultDataSourceName(self) -> AnyStr: ...
    def getDefaultTagProviderName(self) -> AnyStr: ...
    def getEdgeEditions(self) -> List[EdgeEdition]: ...
    def getEventBus(self) -> EventBus: ...
    def getExecutionManager(self) -> ExecutionManager: ...
    def getExpressionFunctionFactory(self) -> FunctionFactory: ...
    def getLaunchContext(self) -> LaunchContext: ...
    def getLicenseState(self, moduleId: AnyStr) -> LicenseState: ...
    def getLocalizationManager(self) -> ClientLocalizationManager: ...
    def getLoggingManager(self) -> LogFilterSettings: ...
    def getModule(self, id_: AnyStr) -> Object: ...
    def getModules(self) -> List[ModuleInfo]: ...
    def getNamedQueryManager(self) -> NamedQueryManager: ...
    def getProgressManager(self) -> ClientProgressManager: ...
    def getProject(self) -> Project: ...
    def getProjectName(self) -> AnyStr: ...
    def getRootPaneContainer(self) -> RootPaneContainer: ...
    def getScriptManager(self) -> ScriptManager: ...
    def getTagManager(self) -> TagManager: ...
    def getTagPollRate(self) -> int: ...
    def getUIEventBus(self) -> EventBus: ...
    def removePropertyChangeListened(self, *args: Any) -> None: ...

class DesktopListener: ...

class LocaleListener:
    def localeChanged(self, newLocale: Locale) -> None: ...

class ClientLocalizationManager(Object):
    def addLocaleListener(self, listener: LocaleListener) -> None: ...
    def addPropertyChangeListener(
        self, propertyName: AnyStr, listener: PropertyChangeListener
    ) -> None: ...
    def get(self, locale: Locale, key: AnyStr) -> AnyStr: ...
    def getAvailableLocales(self) -> List[Locale]: ...
    def getCurrentLocale(self) -> Locale: ...
    def getPreviewLocale(self) -> Locale: ...
    def getStrict(self, *args: Any) -> AnyStr: ...
    def getString(self, key: AnyStr) -> AnyStr: ...
    def getStringForBundleKey(self, bundlekey: AnyStr) -> AnyStr: ...
    def getTranslationsFor(self, key: AnyStr) -> TranslationMap: ...
    def isTranslationEnabled(self) -> bool: ...
    def removeLocaleListener(self, listener: LocaleListener) -> None: ...
    def removePropertyChangeListener(
        self, propertyName: AnyStr, listener: PropertyChangeListener
    ) -> None: ...
    def resetLocale(self) -> None: ...
    def setCurrentLocale(self, locale: Locale) -> None: ...



from typing import Any, Callable, List, Optional, Tuple

from com.inductiveautomation.factorypmi.application import FPMIWindow
from com.inductiveautomation.factorypmi.application.script.builtin import (
    WindowUtilities,
)
from dev.thecesrom.helper.types import AnyNum, AnyStr
from java.awt import Color
from java.org.jdesktop.core.animation.timing import Animator
from java.util import EventObject
from javax.swing import JComponent, JFrame, JPopupMenu

ACCL_NONE: int
ACCL_CONSTANT: int
ACCL_FAST_TO_SLOW: int
ACCL_SLOW_TO_FAST: int
ACCL_EASE: int
COORD_DESIGNER: int
COORD_SCREEN: int

def chooseColor(initialColor: Color, dialogTitle: AnyStr = ...) -> Color: ...
def closeDesktop(handle: AnyStr) -> None: ...
def color(*args: Any) -> Color: ...
def confirm(
    message: AnyStr, title: AnyStr = ..., allowCancel: bool = ...
) -> Optional[bool]: ...
def convertPointToScreen(x: int, y: int, event: EventObject) -> Tuple[int, int]: ...
def createPopupMenu(
    itemNames: List[AnyStr], itemFunctions: List[Callable[..., Any]]
) -> JPopupMenu: ...
def desktop(handle: AnyStr) -> WindowUtilities: ...
def errorBox(message: AnyStr, title: AnyStr = ...) -> None: ...
def findWindow(path: AnyStr) -> List[FPMIWindow]: ...
def getCurrentDesktop() -> AnyStr: ...
def getDesktopHandles() -> List[AnyStr]: ...
def getOpenedWindowNames() -> Tuple[AnyStr, ...]: ...
def getOpenedWindows() -> Tuple[FPMIWindow, ...]: ...
def getParentWindow(event: EventObject) -> FPMIWindow: ...
def getQuality(component: JComponent, propertyName: AnyStr) -> int: ...
def getScreenIndex() -> int: ...
def getScreens() -> List[Tuple[AnyStr, int, int]]: ...
def getSibling(event: EventObject, name: AnyStr) -> FPMIWindow: ...
def getWindow(name: AnyStr) -> FPMIWindow: ...
def getWindowNames() -> Tuple[AnyStr, ...]: ...
def inputBox(message: AnyStr, defaultText: AnyStr = ...) -> Optional[AnyStr]: ...
def isTouchscreenModeEnabled() -> bool: ...
def messageBox(message: AnyStr, title: AnyStr = ...) -> None: ...
def openDesktop(
    screen: int = ...,
    handle: Optional[AnyStr] = ...,
    title: Optional[AnyStr] = ...,
    width: Optional[int] = ...,
    height: Optional[int] = ...,
    x: int = ...,
    y: int = ...,
    windows: Optional[List[AnyStr]] = ...,
) -> JFrame: ...
def openDiagnostics() -> None: ...
def passwordBox(
    message: AnyStr, title: AnyStr = ..., echoChar: AnyStr = ...
) -> Optional[AnyStr]: ...
def setScreenIndex(index: int) -> None: ...
def setTouchscreenModeEnabled(enabled: bool) -> None: ...
def showNumericKeypad(
    initialValue: AnyNum, fontSize: Optional[int] = ..., usePasswordMode: bool = ...
) -> AnyNum: ...
def showTouchscreenKeyboard(
    initialText: AnyStr,
    fontSize: Optional[int] = ...,
    passwordMode: Optional[bool] = ...,
) -> AnyStr: ...
def transform(
    component: JComponent,
    newX: Optional[int] = ...,
    newY: Optional[int] = ...,
    newWidth: Optional[int] = ...,
    newHeight: Optional[int] = ...,
    duration: int = ...,
    callback: Optional[Callable[..., Any]] = ...,
    framesPerSecond: int = ...,
    acceleration: Optional[int] = ...,
    coordSpace: Optional[int] = ...,
) -> Animator: ...
def warningBox(message: AnyStr, title: AnyStr = ...) -> None: ...



from typing import Any, List, Optional

from dev.thecesrom.helper.types import AnyStr
from java.lang import Object
from java.util import Locale

class LocaleUtils(Object):
    @staticmethod
    def getAvailableLocales(andRegionalVariants: bool) -> List[Locale]: ...
    @staticmethod
    def parseLocale(locale: AnyStr) -> Optional[Locale]: ...

class LocalizedString(Object):
    def __init__(self, *args: Any) -> None: ...
    def compareTo(self, other: LocalizedString) -> int: ...
    @staticmethod
    def createRaw(stringVal: AnyStr) -> LocalizedString: ...
    def getDefaultVal(self) -> AnyStr: ...
    def getKey(self) -> AnyStr: ...
    def getParams(self) -> List[Object]: ...
    def setDefaultVal(self, defaultVal: AnyStr) -> None: ...
    def setKey(self, key: AnyStr) -> None: ...
    def setParams(self, params: List[Object]) -> None: ...
    def toString(self, locale: Optional[Locale] = ...) -> AnyStr: ...



from typing import Any, Iterable, Optional

from java.lang import Object
from java.util import AbstractCollection, Comparator
from java.util.stream import Collector

class ImmutableCollection(AbstractCollection):
    def asList(self) -> ImmutableList: ...
    def contains(self, o: Object) -> bool: ...

    class Builder(Object):
        def add(self, *elements: Any) -> ImmutableCollection.Builder: ...
        def addAll(self, elements: Any) -> ImmutableCollection.Builder: ...
        def build(self) -> ImmutableCollection: ...

class ImmutableList(ImmutableCollection):
    @staticmethod
    def builder() -> ImmutableList.Builder: ...
    @staticmethod
    def builderWithExpectedSize() -> ImmutableList.Builder: ...
    def contains(self, o: Object) -> bool: ...
    @staticmethod
    def copyOf(*args: Any) -> ImmutableList: ...
    def indexOf(self, obj: Object) -> int: ...
    def lastIndexOf(self, obj: Object) -> int: ...
    def listIterator(self, index: Optional[int] = ...) -> UnmodifiableListIterator: ...
    @staticmethod
    def of(*args: Any) -> ImmutableList: ...
    @staticmethod
    def sortedCopyOf(
        comparator: Comparator, elements: Iterable[Any]
    ) -> ImmutableList: ...
    def subList(self, fromIndex: int, toIndex: int) -> ImmutableList: ...
    @staticmethod
    def toImmutableList() -> Collector: ...

    class Builder(ImmutableCollection.Builder):
        def build(self) -> ImmutableList: ...

class ImmutableSet(ImmutableCollection):
    @staticmethod
    def builder() -> ImmutableSet.Builder: ...
    @staticmethod
    def builderWithExpectedSize() -> ImmutableSet.Builder: ...
    def contains(self, o: Object) -> bool: ...
    @staticmethod
    def copyOf(*args: Any) -> ImmutableSet: ...
    @staticmethod
    def of(*args: Any) -> ImmutableSet: ...
    @staticmethod
    def toImmutableSet() -> Collector: ...

    class Builder(ImmutableCollection.Builder):
        def __init__(self) -> None: ...
        def build(self) -> ImmutableSet: ...

class UnmodifiableIterator(Object):
    def remove(self) -> None: ...

class UnmodifiableListIterator(UnmodifiableIterator):
    def add(self, e: Any) -> None: ...
    def set(self, e: Any) -> None: ...



from typing import Any, Dict, List, Optional, Tuple

from com.inductiveautomation.ignition.common import BasicDataset
from dev.thecesrom.helper.types import AnyStr

def copyEquipment(
    equipmentSource: AnyStr,
    newEquipmentName: AnyStr,
    enabled: bool,
    activeAddress: AnyStr,
    activePort: int,
    passiveAddress: AnyStr,
    passivePort: int,
    deviceId: int,
    dbTablePrefix: Optional[AnyStr] = ...,
    description: Optional[AnyStr] = ...,
) -> None: ...
def deleteToolProgram(ppid: AnyStr) -> None: ...
def enableDisableEquipment(
    enable: bool, names: Tuple[AnyStr, ...]
) -> List[unicode]: ...
def getResponse(
    transactionID: int, equipment: AnyStr, timeout: int = ..., poll: int = ...
) -> Any: ...
def getToolProgram(ppid: AnyStr) -> Dict[AnyStr, Any]: ...
def getToolProgramDataset() -> BasicDataset: ...
def sendRequest(
    streamFunction: AnyStr, reply: bool, body: Any, equipment: AnyStr
) -> int: ...
def sendResponse(
    transactionID: int,
    systemBytes: int,
    streamFunction: AnyStr,
    body: Any,
    equipment: AnyStr,
) -> None: ...
def startSimEventRun(simulatorName: AnyStr, eventRunName: AnyStr) -> None: ...
def toDataSet(secsObject: Any) -> BasicDataset: ...
def toTreeDataSet(dataset: BasicDataset) -> BasicDataset: ...



from typing import Optional

from com.inductiveautomation.ignition.common.gson import Gson, JsonObject
from com.inductiveautomation.ignition.common.jsonschema import JsonSchema
from com.inductiveautomation.ignition.common.util import LoggerEx
from dev.thecesrom.helper.types import AnyStr
from java.lang import Object
from java.util.function import Consumer

class PerspectiveModule(Object):
    LOG_PREFIX: AnyStr
    META_SCHEMA: JsonSchema
    MODULE_ID: AnyStr
    SESSION_PROPS_SCHEMA: JsonSchema
    VIEW_SCHEMA: JsonSchema
    @staticmethod
    def createPerspectiveCompatibleGson(
        customize: Optional[Consumer] = ...,
    ) -> Gson: ...
    @staticmethod
    def defaultMetaProps() -> JsonObject: ...
    @staticmethod
    def defaultSessionProps() -> JsonObject: ...
    @staticmethod
    def defaultViewProps() -> JsonObject: ...
    @staticmethod
    def getLogger(name: AnyStr) -> LoggerEx: ...



from typing import Any, Iterable, List, Union

from dev.thecesrom.helper.types import AnyStr
from java.beans import PropertyChangeListener
from java.lang import Class, Object
from java.util import Collection

class Property:
    def getDefaultValue(self) -> Any: ...
    def getName(self) -> AnyStr: ...
    def getType(self) -> Class: ...

class PropertySet:
    @staticmethod
    def builder() -> BasicPropertySet.Builder: ...
    def extend(self, parent: PropertySet) -> PropertySet: ...
    def isExtended(self, prop: Property) -> bool: ...
    def newDefaultInstance(self) -> PropertySet: ...
    def newExtension(self) -> PropertySet: ...

class PropertyValueSource:
    def contains(self, prop: Property) -> bool: ...
    def get(self, prop: Property) -> Any: ...
    def getNonNull(self, *args: Any) -> Any: ...
    def getOrDefault(self, prop: Property) -> Any: ...
    def getOrElse(self, prop: Property) -> Any: ...
    def getProperties(self) -> Collection: ...
    def getValues(self) -> List[PropertyValue]: ...

class BasicProperty(Property, Object):
    def __init__(self, *args: Any) -> None: ...
    def getClazz(self) -> Class: ...
    def getDefaultValue(self) -> Any: ...
    def getName(self) -> AnyStr: ...
    def getType(self) -> Class: ...
    def setClazz(self, clazz: Class) -> None: ...
    def setClazz_(self, clazz: Class) -> BasicProperty: ...
    def setDefaultValue(self, defaultValue: Any) -> None: ...
    def setDefaultValue_(self, defaultValue: Any) -> BasicProperty: ...
    def setName(self, name: AnyStr) -> None: ...
    def setName_(self, name: AnyStr) -> BasicProperty: ...

class BasicPropertySet(Object):
    def __init__(self, *args: Any) -> None: ...
    def addPropertySet(self, *args: Any) -> None: ...
    def contains(self, prop: Property) -> bool: ...
    def get(self, prop: Property) -> Any: ...
    def getCount(self) -> int: ...
    def getExtension(self) -> PropertySet: ...
    def getOrDefault(self, prop: Property) -> Any: ...
    def getOrElse(self, prop: Property, value: Any) -> Any: ...
    def getProperties(self) -> List[Property]: ...
    def getRawValueMap(self) -> Any: ...
    def getValues(self) -> List[PropertyValue]: ...
    def isExtended(self, prop: Property) -> bool: ...
    def isInherited(self, prop: Property) -> bool: ...
    def iterator(self) -> Iterable[PropertyValue]: ...
    @staticmethod
    def of(*args: PropertyValue) -> PropertySet: ...
    def remove(self, prop: Property) -> None: ...
    def removePropertyChangeListener(
        self, listener: PropertyChangeListener
    ) -> None: ...
    def set(self, prop: Union[Property, PropertyValue], value: Any) -> None: ...
    def setDirect(self, prop: Property, value: Object) -> None: ...
    def setRawValueMap(self, copy: Any) -> None: ...

    class Builder(Object):
        def build(self) -> BasicPropertySet: ...
        def set(self, prop: Property, value: Any) -> BasicPropertySet.Builder: ...

class PropertyValue(Object):
    def __init__(self, *args: Any) -> None: ...
    def getProperty(self) -> Property: ...
    def getValue(self) -> Object: ...
    @staticmethod
    def of(prop: Property, value: Object) -> PropertyValue: ...



from typing import Any, Iterable, List, Optional, Tuple, Union

from com.google.common.eventbus import EventBus
from com.inductiveautomation.ignition.common.expressions import FunctionFactory
from com.inductiveautomation.ignition.common.licensing import LicenseState
from com.inductiveautomation.ignition.common.logging import LogFilterSettings
from com.inductiveautomation.ignition.common.script import ScriptManager
from com.inductiveautomation.ignition.common.tags.model import TagManager
from com.inductiveautomation.ignition.common.xmlserialization.deserialization import (
    XMLDeserializer,
)
from dev.thecesrom.helper.types import AnyStr
from java.io import InputStream
from java.lang import Enum, Object, String

class CommonContext:
    def createDeserializer(self) -> XMLDeserializer: ...
    def getEdgeEditions(self) -> List[EdgeEdition]: ...
    def getEventBus(self) -> EventBus: ...
    def getExpressionFunctionFactory(self) -> FunctionFactory: ...
    def getLicenseState(self, moduleId: AnyStr) -> LicenseState: ...
    def getLoggingManager(self) -> LogFilterSettings: ...
    def getModule(self, id_: AnyStr) -> Object: ...
    def getScriptManager(self) -> ScriptManager: ...
    def getTagManager(self) -> TagManager: ...

class ApplicationScope(Object):
    ALL: int
    CLIENT: int
    DESIGNER: int
    GATEWAY: int
    NONE: int
    @staticmethod
    def getGlobalScope() -> int: ...
    @staticmethod
    def getScopePrefix() -> AnyStr: ...
    @staticmethod
    def init(globalScope: int) -> None: ...
    @staticmethod
    def isClient(scope: int) -> bool: ...
    @staticmethod
    def isDesigner(scope: int) -> bool: ...
    @staticmethod
    def isGateway(scope: int) -> bool: ...
    @staticmethod
    def parseScope(s: AnyStr) -> int: ...
    @staticmethod
    def toCode(scope: int) -> AnyStr: ...

class EdgeEdition(Enum):
    @staticmethod
    def create(edgeFlags: List[String]) -> List[EdgeEdition]: ...
    @staticmethod
    def getAllEditions() -> List[EdgeEdition]: ...
    @staticmethod
    def values() -> Iterable[EdgeEdition]: ...

class Version(Object):
    build: int
    dev: bool
    major: int
    minor: int
    rev: int
    beta: int
    rc: int
    snapshot: bool
    def __init__(
        self,
        major: int = ...,
        minor: int = ...,
        rev: int = ...,
        build: int = ...,
        beta: int = ...,
        rc: int = ...,
    ) -> None: ...
    def __eq__(self, other: Any) -> bool: ...
    def compareTo(self, that: Version) -> Optional[int]: ...
    def exists(self) -> bool: ...
    @staticmethod
    def fromXML(inputStream: InputStream) -> Version: ...
    def getBasicString(self) -> str: ...
    def getBeta(self) -> int: ...
    def getBuildNumber(self) -> int: ...
    def getMajor(self) -> int: ...
    def getMinor(self) -> int: ...
    def getRc(self) -> int: ...
    def getRevision(self) -> int: ...
    def getXML(self) -> str: ...
    def isDev(self) -> bool: ...
    def isFutureVersion(self, arg: Union[Version, AnyStr]) -> bool: ...
    def isSnapshot(self) -> bool: ...
    @staticmethod
    def parse(s: AnyStr) -> Version: ...
    def toParseableString(self) -> str: ...
    def toString(self) -> str: ...
    def toTuple(self, strict: bool = ...) -> Tuple[int, ...]: ...



from typing import Union

from dev.thecesrom.helper.types import AnyStr
from java.util import HashMap

class TranslationMap(HashMap):
    def __init__(self, arg: Union[AnyStr, TranslationMap]) -> None: ...
    def getKey(self) -> AnyStr: ...



from typing import Any

from java.lang import Object

class Dimension2D(Object):
    def getHeight(self) -> float: ...
    def getWidth(self) -> float: ...
    def setSize(self, *args: Any) -> None: ...

class Point2D(Object):
    def clone(self) -> Object: ...
    def distance(self, *args: Any) -> float: ...
    def distanceSq(self, *args: Any) -> float: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    def setLocation(self, *args: Any) -> None: ...

    class Double(Object):
        x: float
        y: float
        def __init__(self, x: float = ..., y: float = ...) -> None: ...
        def clone(self) -> Object: ...
        def distance(self, *args: Any) -> float: ...
        def distanceSq(self, *args: Any) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def setLocation(self, x: float, y: float) -> None: ...

    class Float(Object):
        x: float
        y: float
        def __init__(self, x: float = ..., y: float = ...) -> None: ...
        def clone(self) -> Object: ...
        def distance(self, *args: Any) -> float: ...
        def distanceSq(self, *args: Any) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def setLocation(self, x: float, y: float) -> None: ...



from typing import Any

from java.lang import Object

class Binding:
    def update(self, *args: Any) -> None: ...

class DefaultBindableModel(Object):
    def __init__(self) -> None: ...
    def bind(self, toBind: Binding) -> None: ...
    def modelUpdated(self, *args: Any) -> None: ...
    def unbind(self, toUnbind: Binding) -> None: ...
    def unbindAll(self) -> None: ...
    def update(self) -> None: ...



from typing import Any

from java.lang import Object

class DocumentElement(Object):
    def __init__(self, *args: Any) -> None: ...

class Document(DocumentElement):
    def __init__(self, *args: Any) -> None: ...



from typing import Any, Optional, Union

from java.lang import Appendable, CharSequence, Object

class Buffer(Object):
    def array(self) -> Object: ...
    def arrayOffset(self) -> int: ...
    def capacity(self) -> int: ...
    def clear(self) -> Buffer: ...
    def duplicate(self) -> Buffer: ...
    def flip(self) -> Buffer: ...
    def hasArray(self) -> bool: ...
    def hasRemaining(self) -> bool: ...
    def isDirect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def limit(self, nrewLimit: Optional[int] = ...) -> Union[Buffer, int]: ...
    def mark(self) -> Buffer: ...
    def position(self, newPosition: Optional[int] = ...) -> Union[Buffer, int]: ...
    def remaining(self) -> int: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    def slice(self) -> Buffer: ...

class ByteBuffer(Buffer):
    def alignedSlice(self, unitSize: int) -> ByteBuffer: ...
    def alignmentOffset(self, index: int, unitSize: int) -> int: ...
    @staticmethod
    def allocate(capacity: int) -> ByteBuffer: ...
    @staticmethod
    def allocateDirect(capacity: int) -> ByteBuffer: ...
    def array(self) -> Object: ...
    def arrayOffset(self) -> int: ...
    def asCharBuffer(self) -> CharBuffer: ...
    def asDoubleBuffer(self) -> DoubleBuffer: ...
    def asFloatBuffer(self) -> FloatBuffer: ...
    def asIntBuffer(self) -> IntBuffer: ...
    def asLongBuffer(self) -> LongBuffer: ...
    def asReadOnlyBuffer(self) -> ByteBuffer: ...
    def asShortBuffer(self) -> ShortBuffer: ...
    def compact(self) -> ByteBuffer: ...
    def compareTo(self, that: ByteBuffer) -> int: ...
    def duplicate(self) -> Buffer: ...
    def get(self, *args: Any) -> ByteBuffer: ...
    def getChar(self, index: int = ...) -> str: ...
    def getDouble(self, index: int = ...) -> float: ...
    def getFloat(self, index: int = ...) -> float: ...
    def getInt(self, index: int = ...) -> int: ...
    def getLong(self, index: int = ...) -> long: ...
    def getShort(self, index: int = ...) -> int: ...
    def hasArray(self) -> bool: ...
    def isDirect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def mismatch(self, that: ByteBuffer) -> int: ...
    def order(self, bo: Optional[ByteOrder] = ...) -> ByteOrder: ...
    def put(self, *args: Any) -> ByteBuffer: ...
    def putChar(self, *args: Any) -> ByteBuffer: ...
    def putDouble(self, *args: Any) -> ByteBuffer: ...
    def putFloat(self, *args: Any) -> ByteBuffer: ...
    def putInt(self, *args: Any) -> ByteBuffer: ...
    def putLong(self, *args: Any) -> ByteBuffer: ...
    def putShort(self, *args: Any) -> ByteBuffer: ...
    def slice(self) -> ByteBuffer: ...
    @staticmethod
    def wrap(*arg: Any) -> ByteBuffer: ...

class ByteOrder(Object):
    BIG_ENDIAN: ByteOrder
    LITTLE_ENDIAN: ByteOrder
    @staticmethod
    def nativeOrder() -> ByteOrder: ...

class CharBuffer(Buffer, Appendable, CharSequence):
    @staticmethod
    def allocate(capacity: int) -> CharBuffer: ...
    def append(
        self, c_csq: Union[CharSequence, str], start: int = ..., end: int = ...
    ) -> CharBuffer: ...
    def array(self) -> Object: ...
    def arrayOffset(self) -> int: ...
    def charAt(self, index: int) -> str: ...
    def compact(self) -> CharBuffer: ...
    def compareTo(self, that: CharBuffer) -> int: ...
    def duplicate(self) -> CharBuffer: ...
    def get(self, *args: Any) -> CharBuffer: ...
    def hasArray(self) -> bool: ...
    def isDirect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def length(self) -> int: ...
    def mismatch(self, that: CharBuffer) -> int: ...
    def order(self) -> ByteOrder: ...
    def put(self, *args: Any) -> CharBuffer: ...
    def read(self, target: CharBuffer) -> int: ...
    def slice(self) -> CharBuffer: ...
    def subSequence(self, start: int, end: int) -> CharSequence: ...
    @staticmethod
    def wrap(*args: Any) -> CharBuffer: ...

class DoubleBuffer(Buffer):
    @staticmethod
    def allocate(capacity: int) -> DoubleBuffer: ...
    def array(self) -> Object: ...
    def arrayOffset(self) -> int: ...
    def compact(self) -> DoubleBuffer: ...
    def compareTo(self, that: DoubleBuffer) -> int: ...
    def duplicate(self) -> DoubleBuffer: ...
    def get(self, *args: Any) -> DoubleBuffer: ...
    def hasArray(self) -> bool: ...
    def isDirect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def mismatch(self, that: DoubleBuffer) -> int: ...
    def order(self) -> ByteOrder: ...
    def put(self, *args: Any) -> DoubleBuffer: ...
    def slice(self) -> DoubleBuffer: ...
    @staticmethod
    def wrap(*args: Any) -> DoubleBuffer: ...

class FloatBuffer(Buffer):
    @staticmethod
    def allocate(capacity: int) -> FloatBuffer: ...
    def array(self) -> Object: ...
    def arrayOffset(self) -> int: ...
    def compact(self) -> FloatBuffer: ...
    def compareTo(self, that: FloatBuffer) -> int: ...
    def duplicate(self) -> FloatBuffer: ...
    def get(self, *args: Any) -> FloatBuffer: ...
    def hasArray(self) -> bool: ...
    def isDirect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def mismatch(self, that: FloatBuffer) -> int: ...
    def order(self) -> ByteOrder: ...
    def put(self, *args: Any) -> FloatBuffer: ...
    def slice(self) -> FloatBuffer: ...
    @staticmethod
    def wrap(*args: Any) -> FloatBuffer: ...

class IntBuffer(Buffer):
    @staticmethod
    def allocate(capacity: int) -> IntBuffer: ...
    def array(self) -> Object: ...
    def arrayOffset(self) -> int: ...
    def compact(self) -> IntBuffer: ...
    def compareTo(self, that: IntBuffer) -> int: ...
    def duplicate(self) -> IntBuffer: ...
    def get(self, *args: Any) -> IntBuffer: ...
    def hasArray(self) -> bool: ...
    def isDirect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def mismatch(self, that: IntBuffer) -> int: ...
    def order(self) -> ByteOrder: ...
    def put(self, *args: Any) -> IntBuffer: ...
    def slice(self) -> IntBuffer: ...
    @staticmethod
    def wrap(*args: Any) -> IntBuffer: ...

class LongBuffer(Buffer):
    @staticmethod
    def allocate(capacity: int) -> LongBuffer: ...
    def array(self) -> Object: ...
    def arrayOffset(self) -> int: ...
    def compact(self) -> LongBuffer: ...
    def compareTo(self, that: LongBuffer) -> int: ...
    def duplicate(self) -> LongBuffer: ...
    def get(self, *args: Any) -> LongBuffer: ...
    def hasArray(self) -> bool: ...
    def isDirect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def mismatch(self, that: LongBuffer) -> int: ...
    def order(self) -> ByteOrder: ...
    def put(self, *args: Any) -> LongBuffer: ...
    def slice(self) -> LongBuffer: ...
    @staticmethod
    def wrap(*args: Any) -> LongBuffer: ...

class ShortBuffer(Buffer):
    @staticmethod
    def allocate(capacity: int) -> ShortBuffer: ...
    def array(self) -> Object: ...
    def arrayOffset(self) -> int: ...
    def compact(self) -> ShortBuffer: ...
    def compareTo(self, that: ShortBuffer) -> int: ...
    def duplicate(self) -> ShortBuffer: ...
    def get(self, *args: Any) -> ShortBuffer: ...
    def hasArray(self) -> bool: ...
    def isDirect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def mismatch(self, that: ShortBuffer) -> int: ...
    def order(self) -> ByteOrder: ...
    def put(self, *args: Any) -> ShortBuffer: ...
    def slice(self) -> ShortBuffer: ...
    @staticmethod
    def wrap(*args: Any) -> ShortBuffer: ...

class MappedByteBuffer(ByteBuffer):
    def force(self) -> MappedByteBuffer: ...
    def isLoaded(self) -> bool: ...
    def load(self) -> MappedByteBuffer: ...



from typing import Any

from java.lang import IllegalArgumentException, Number
from org.apache.commons.math3.exception.util import ExceptionContext

class MathIllegalArgumentException(IllegalArgumentException):
    def __init__(self, *args: Any) -> None: ...
    def getContext(self) -> ExceptionContext: ...

class MathIllegalNumberException(MathIllegalArgumentException):
    INTEGER_ZERO: int
    def getArgument(self) -> Number: ...

class DimensionMismatchException(MathIllegalNumberException):
    def __init__(self, *args: Any) -> None: ...
    def getDimension(self) -> int: ...



from typing import Any

import org.slf4j.event
from dev.thecesrom.helper.types import AnyStr
from java.lang import Object

class Level(Object):
    @staticmethod
    def convertAnSLF4JLevel(slf4jLevel: org.slf4j.event.Level) -> Level: ...
    @staticmethod
    def fromLocationAwareLoggerInteger(levelInt: int) -> Level: ...
    def isGreaterOrEqual(self, r: Level) -> bool: ...
    def toInt(self) -> int: ...
    def toInteger(self) -> int: ...
    @staticmethod
    def toLevel(*args: Any) -> Level: ...
    @staticmethod
    def toLocationAwareLoggerInteger(level: Level) -> int: ...
    @staticmethod
    def valueOf(sArg: AnyStr) -> Level: ...



from typing import Any, List, Optional

from dev.thecesrom.helper.types import AnyStr as AnyStr
from java.lang import Object

class KeyboardLayout(Object):
    alias: AnyStr
    id: Any
    labels: Optional[Any]
    name: AnyStr
    rows: Optional[List[Any]]
    title: AnyStr
    supportedLanguages: Optional[List[AnyStr]]
    def __init__(
        self,
        id: Any,
        name: AnyStr,
        title: AnyStr,
        alias: AnyStr,
        rows: Optional[List[Any]] = ...,
        supportedLanguages: Optional[List[AnyStr]] = ...,
        labels: Optional[Any] = ...,
    ) -> None: ...
    def getAlias(self) -> AnyStr: ...
    def getId(self) -> Any: ...
    def getLabels(self) -> Optional[Any]: ...
    def getName(self) -> AnyStr: ...
    def getRows(self) -> Optional[List[Any]]: ...
    def getSupportedLanguages(self) -> Optional[List[AnyStr]]: ...



from typing import Any, Optional

from dev.thecesrom.helper.types import AnyStr
from java.lang import Exception, Object
from java.util import Enumeration

class OptionHandler:
    def activateOptions(self) -> None: ...

class ErrorHandler(OptionHandler):
    def activateOptions(self) -> None: ...
    def error(
        self,
        message: AnyStr,
        e: Optional[Exception] = ...,
        errorCode: Optional[int] = ...,
        event: Optional[LoggingEvent] = ...,
    ) -> None: ...
    def setAppender(self, appender: Any) -> None: ...
    def setBackupAppender(self, appender: Any) -> None: ...
    def setLogger(self, logger: Any) -> None: ...

class HierarchyEventListener:
    def addAppenderEvent(self, cat: Any, appender: Any) -> None: ...
    def removeAppenderEvent(self, cat: Any, appender: Any) -> None: ...

class LoggerFactory:
    def makeNewLoggerInstance(self, name: AnyStr) -> Any: ...

class LoggerRepository:
    def addHierarchyEventListener(self, listener: HierarchyEventListener) -> None: ...
    def emitNoAppenderWarning(self, cat: Any) -> None: ...
    def exists(self, name: AnyStr) -> Any: ...
    def fireAddAppenderEvent(self, logger: Any, appender: Any) -> None: ...
    def getCurrentLoggers(self) -> Enumeration: ...
    def getLogger(
        self, name: AnyStr, factory: Optional[LoggerFactory] = ...
    ) -> Any: ...
    def getRootLogger(self) -> Any: ...
    def getThreshold(self) -> Any: ...
    def isDisabled(self, level: int) -> bool: ...
    def resetConfiguration(self) -> None: ...
    def setThreshold(self, arg: Any) -> None: ...
    def shutdown(self) -> None: ...

class Filter(Object, OptionHandler):
    def activateOptions(self) -> None: ...
    def decide(self, event: LoggingEvent) -> int: ...
    def getNext(self) -> Filter: ...
    def setNext(self, next: Filter) -> None: ...

class LoggingEvent(Object):
    categoryName: AnyStr
    fqnOfCategoryClass: AnyStr
    level: Any
    timeStamp: long
    def __init__(self, *args: Any) -> None: ...



from typing import List, Mapping, Optional

from com.inductiveautomation.ignition.common.licensing import LicenseState
from com.inductiveautomation.ignition.common.model import Version
from com.inductiveautomation.ignition.common.util import Platform
from dev.thecesrom.helper.types import AnyStr
from java.lang import Object

class ModuleInfo(Object):
    def getCrc(self) -> long: ...
    def getDependencies(
        self, scope: Optional[int] = ...
    ) -> List[ModuleInfo.ModuleDependency]: ...
    def getDescription(self) -> AnyStr: ...
    def getDocumentationRoot(self) -> AnyStr: ...
    def getExports(self) -> List[ModuleInfo.JarInfo]: ...
    def getHooks(self) -> Mapping[int, AnyStr]: ...
    def getId(self) -> AnyStr: ...
    def getInstallPath(self) -> AnyStr: ...
    def getJars(self) -> List[ModuleInfo.JarInfo]: ...
    def getLibsRequired(self) -> List[ModuleInfo.LibraryInfo]: ...
    def getLicenseFile(self) -> AnyStr: ...
    def getLicenseState(self) -> LicenseState: ...
    def getName(self) -> AnyStr: ...
    def getRequiredFrameworkVersion(self) -> int: ...
    def getRequiredIgnitionVersion(self) -> Version: ...
    def getVendorContactInfo(self) -> AnyStr: ...
    def getVendorId(self) -> int: ...
    def getVendorName(self) -> AnyStr: ...
    def getVersion(self) -> Version: ...
    def isFree(self) -> bool: ...
    def isMakerEditionCompatible(self) -> bool: ...
    def isSelfSigned(self) -> bool: ...
    def isTrialMode(self) -> bool: ...
    @staticmethod
    def newBuilder() -> ModuleInfo.Builder: ...
    def setCrc(self, crc: long) -> None: ...
    def setFree(self) -> None: ...
    def setInstallPath(self, installPath: AnyStr) -> None: ...
    def setLicenseState(self, newState: LicenseState) -> None: ...
    def setMakerEditionCompatible(self) -> None: ...
    def setSelfSigned(self) -> None: ...
    def setVendorInfo(
        self, vendorId: int, vendorName: AnyStr, vendorContactInfo: AnyStr
    ) -> None: ...
    @staticmethod
    def setDependencyOrder(
        list_: List[ModuleInfo], scope: int, reverse: bool
    ) -> List[ModuleInfo]: ...
    def toXML(self) -> AnyStr: ...

    class Builder(Object):
        def __init__(self) -> None: ...
        def addDependency(
            self, dependency: ModuleInfo.ModuleDependency
        ) -> ModuleInfo.Builder: ...
        def build(self) -> ModuleInfo: ...
        def setDependencies(
            self, dependencies: List[ModuleInfo.ModuleDependency]
        ) -> ModuleInfo.Builder: ...
        def setDescription(self, description: AnyStr) -> ModuleInfo.Builder: ...
        def setExports(
            self, exports: List[ModuleInfo.JarInfo]
        ) -> ModuleInfo.Builder: ...
        def setHooks(self, hooks: Mapping[int, AnyStr]) -> ModuleInfo.Builder: ...
        def setId(self, id_: AnyStr) -> ModuleInfo.Builder: ...
        def setJars(self, jars: List[ModuleInfo.JarInfo]) -> ModuleInfo.Builder: ...
        def setLicenseFile(self, licenseFilename: AnyStr) -> ModuleInfo.Builder: ...
        def setName(self, name: AnyStr) -> ModuleInfo.Builder: ...
        def setRequire(
            self, require: List[ModuleInfo.LibraryInfo]
        ) -> ModuleInfo.Builder: ...
        def setRequiredFrameworkVersion(
            self, requiredFrameworkVersion: int
        ) -> ModuleInfo.Builder: ...
        def setRequiredIgnitionVersion(
            self, requiredIgnitionVersion: Version
        ) -> ModuleInfo.Builder: ...
        def setSelfSigned(self, selfSigned: bool) -> ModuleInfo.Builder: ...
        def setVendor(
            self, id_: int, name: AnyStr, contactInfo: AnyStr
        ) -> ModuleInfo.Builder: ...
        def setVersion(self, version: Version) -> ModuleInfo.Builder: ...

    class JarInfo(Object):
        def __init__(
            self,
            scope: int,
            path: AnyStr,
            requiredOs: AnyStr = ...,
            requiredArch: AnyStr = ...,
        ) -> None: ...
        def getPath(self) -> AnyStr: ...
        def getRequiredArch(self) -> AnyStr: ...
        def getRequiredOS(self) -> AnyStr: ...
        def getScope(self) -> int: ...
        def isNativeLib(self) -> bool: ...
        def isRequiredArchitecture(self, arch: Platform.Architecture) -> bool: ...
        def isRequiredOS(self, os: Platform.OperatingSystem) -> bool: ...

    class LibraryInfo(Object):
        def getName(self) -> AnyStr: ...
        def getScope(self) -> int: ...
        def setName(self, name: AnyStr) -> None: ...
        def setScope(self, scope: int) -> None: ...

    class ModuleDependency(Object):
        def getModuleId(self) -> AnyStr: ...
        def getScope(self) -> int: ...
        def getVersion(self) -> Version: ...
